@@ -1,9 +1,9 @@
-#![allow(non_snake_case)]
+#![allow(non_camel_case_types, non_snake_case, non_upper_case_globals)]
 
 use crate::co::{ACCESS_RIGHTS, STANDARD_RIGHTS, WM, WS};
 
 pub_struct_const! { KEY, u32,
-	/// [`RegOpenKeyEx`](crate::HKEY::RegOpenKeyEx) `samDesired` (`u32`).
+	/// [`HKEY::RegOpenKeyEx`](crate::HKEY::RegOpenKeyEx) `samDesired` (`u32`).
 	=>
 	QUERY_VALUE, 0x0001
 	SET_VALUE, 0x0002
@@ -229,7 +229,7 @@ pub_struct_const_cmd! { LBN,
 	KILLFOCUS, 5
 }
 
-pub_struct_const_ws! { LBS,
+pub_struct_const_ws! { LBS, u32,
 	/// List box control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/list-box-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
@@ -294,9 +294,9 @@ pub_struct_const_wm! { LM,
 }
 
 pub_struct_const! { LR, u32,
-	/// [`LoadImageBitmap`](crate::HINSTANCE::LoadImageBitmap),
-	/// [`LoadImageCursor`](crate::HINSTANCE::LoadImageCursor) and
-	/// [`LoadImageIcon`](crate::HINSTANCE::LoadImageIcon) `fuLoad`.
+	/// [`HINSTANCE::LoadImageBitmap`](crate::HINSTANCE::LoadImageBitmap),
+	/// [`HINSTANCE::LoadImageCursor`](crate::HINSTANCE::LoadImageCursor) and
+	/// [`HINSTANCE::LoadImageIcon`](crate::HINSTANCE::LoadImageIcon) `fuLoad`.
 	=>
 	DEFAULTCOLOR, 0x0000_0000
 	MONOCHROME, 0x0000_0001
@@ -334,7 +334,7 @@ pub_struct_const! { LV_VIEW, u32,
 }
 
 pub_struct_const! { LVA, u16,
-	/// [`LVM_ARRANGE`](crate::msg::lvm::Arrange) arrangement (`u16`).
+	/// [`lvm::Arrange`](crate::msg::lvm::Arrange) arrangement (`u16`).
 	=>
 	DEFAULT, 0x0000
 	SNAPTOGRID, 0x0005
@@ -372,10 +372,10 @@ pub_struct_const! { LVCFMT_C, i32,
 	IMAGE, 0x0800
 	BITMAP_ON_RIGHT, 0x1000
 	COL_HAS_IMAGES, 0x8000
-	FIXED_WIDTH, 0x00100
-	NO_DPI_SCALE, 0x40000
-	FIXED_RATIO, 0x80000
-	SPLITBUTTON, 0x1000000
+	FIXED_WIDTH, 0x0_0100
+	NO_DPI_SCALE, 0x4_0000
+	FIXED_RATIO, 0x8_0000
+	SPLITBUTTON, 0x100_0000
 }
 
 pub_struct_const! { LVCFMT_I, i32,
@@ -439,7 +439,7 @@ pub_struct_const! { LVHT, u32,
 }
 
 pub_struct_const! { LVIR, u8,
-	/// [`LVM_GETITEMRECT`](crate::msg::lvm::GetItemRect) `portion` (`u8`).
+	/// [`lvm::GetItemRect`](crate::msg::lvm::GetItemRect) `portion` (`u8`).
 	=>
 	BOUNDS, 0
 	ICON, 1
@@ -452,7 +452,8 @@ pub_struct_const! { LVIS, u32,
 	/// [states](https://docs.microsoft.com/en-us/windows/win32/controls/list-view-item-states)
 	/// (`u32`).
 	=>
-	NONE, 0
+	/// None of the actual values (zero).
+	NoValue, 0
 	FOCUSED, 0x0001
 	SELECTED, 0x0002
 	CUT, 0x0004
@@ -662,7 +663,7 @@ pub_struct_const_nm! { LVN,
 }
 
 pub_struct_const! { LVNI, u32,
-	/// [`LVM_GETNEXTITEM`](crate::msg::lvm::GetNextItem) relationship (`u32`).
+	/// [`lvm::GetNextItem`](crate::msg::lvm::GetNextItem) relationship (`u32`).
 	=>
 	ALL, 0x0000
 	FOCUSED, 0x0001
@@ -679,7 +680,7 @@ pub_struct_const! { LVNI, u32,
 	TORIGHT, 0x0800
 }
 
-pub_struct_const_ws! { LVS,
+pub_struct_const_ws! { LVS, u32,
 	/// List view control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/list-view-window-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
@@ -713,7 +714,8 @@ pub_struct_const_wsex! { LVS_EX,
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/extended-list-view-styles)
 	/// (`u32`), convertible to [`WS_EX`](crate::co::WS_EX).
 	=>
-	NONE, 0
+	/// None of the actual values (zero).
+	NoValue, 0
 	AUTOAUTOARRANGE, 0x0100_0000
 	AUTOCHECKSELECT, 0x0800_0000
 	AUTOSIZECOLUMNS, 0x1000_0000
@@ -746,7 +748,16 @@ pub_struct_const_wsex! { LVS_EX,
 	UNDERLINEHOT, 0x0000_0800
 }
 
-pub_struct_const_ws! { LWS,
+pub_struct_const! { LVSIL, u8,
+	/// [`lvm::GetImageList`](crate::msg::lvm::GetImageList) `kind` (`u8`).
+	=>
+	NORMAL, 0
+	SMALL, 1
+	STATE, 2
+	GROUPHEADER, 3
+}
+
+pub_struct_const_ws! { LWS, u32,
 	/// SysLink control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/syslink-control-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
