@@ -1,3 +1,5 @@
+#![allow(non_camel_case_types, non_upper_case_globals)]
+
 use crate::co::{ACCESS_RIGHTS, CCM, WM};
 
 pub_struct_const_wm! { SB,
@@ -25,21 +27,22 @@ pub_struct_const_wm! { SB,
 	SETBKCOLOR, CCM::SETBKCOLOR.0
 }
 
-pub_struct_const_ws! { SBARS,
+pub_struct_const_ws! { SBARS, u32,
 	/// Status bar control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/status-bar-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
 	=>
-	NONE, 0
+	/// None of the actual values (zero).
+	NoValue, 0
 	SIZEGRIP, 0x0100
 	TOOLTIPS, 0x0800
 }
 
 pub_struct_const! { SBB, i32,
-	/// [`GetScrollInfo`](crate::HWND::GetScrollInfo),
-	/// [`SetScrollInfo`](crate::HWND::SetScrollInfo) and
-	/// [`SetScrollRange`](crate::HWND::SetScrollRange) `nBar` (`i32`). Originally
-	/// has `SB` prefix.
+	/// [`HWND::GetScrollInfo`](crate::HWND::GetScrollInfo),
+	/// [`HWND::SetScrollInfo`](crate::HWND::SetScrollInfo) and
+	/// [`HWND::SetScrollRange`](crate::HWND::SetScrollRange) `nBar` (`i32`).
+	/// Originally has `SB` prefix.
 	=>
 	HORZ, 0
 	VERT, 1
@@ -57,11 +60,11 @@ pub_struct_const_nm! { SBN,
 }
 
 pub_struct_const! { SBT, u16,
-	/// [`SB_GETTEXT`](crate::msg::sb::GetText),
-	/// [`SB_GETTEXTLENGTH`](crate::msg::sb::GetTextLength) and
-	/// [`SB_SETTEXT`](crate::msg::sb::SetText) drawing operation (`u16`).
+	/// [`sb::GetText`](crate::msg::sb::GetText),
+	/// [`sb::GetTextLength`](crate::msg::sb::GetTextLength) and
+	/// [`sb::SetText`](crate::msg::sb::SetText) drawing operation (`u16`).
 	=>
-	NONE, 0
+	BORDER, 0
 	OWNERDRAW, 0x1000
 	NOBORDERS, 0x0100
 	POPOUT, 0x0200
@@ -70,8 +73,8 @@ pub_struct_const! { SBT, u16,
 }
 
 pub_struct_const! { SB_REQ, u16,
-	/// [`WM_HSCROLL`](crate::msg::wm::HScroll) and
-	/// [`WM_VSCROLL`](crate::msg::wm::VScroll) request (`u16`). Originally has
+	/// [`wm::HScroll`](crate::msg::wm::HScroll) and
+	/// [`wm::VScroll`](crate::msg::wm::VScroll) request (`u16`). Originally has
 	/// `SB` prefix.
 	=>
 	LINEUP, 0
@@ -92,7 +95,7 @@ pub_struct_const! { SB_REQ, u16,
 }
 
 pub_struct_const! { SC, u32,
-	/// [`WM_SYSCOMMAND`](crate::msg::wm::SysCommand) type of system command
+	/// [`wm::SysCommand`](crate::msg::wm::SysCommand) type of system command
 	/// requested (`u32`).
 	=>
 	CLOSE, 0xf060
@@ -100,7 +103,7 @@ pub_struct_const! { SC, u32,
 	DEFAULT, 0xf160
 	HOTKEY, 0xf150
 	HSCROLL, 0xf080
-	ISSECURE, 0x00000001
+	ISSECURE, 0x0000_0001
 	KEYMENU, 0xf100
 	MAXIMIZE, 0xf030
 	MINIMIZE, 0xf020
@@ -128,6 +131,25 @@ pub_struct_const! { SCS, u32,
 	W_64BIT_BINARY, 6
 }
 
+pub_struct_const! { SE_ERR, u32,
+	/// [`HWND::ShellExecute`](crate::HWND::ShellExecute) return value (`u32`).
+	=>
+	FILE_NOT_FOUND, 2
+	PATH_NOT_FOUND, 3
+	BAD_FORMAT, 11
+
+	ACCESSDENIED, 5
+	OOM, 8
+	DLLNOTFOUND, 32
+
+	SHARE, 26
+	ASSOCINCOMPLETE, 27
+	DDETIMEOUT, 28
+	DDEFAIL, 29
+	DDEBUSY, 30
+	NOASSOC, 31
+}
+
 pub_struct_const! { SECTION, u32,
 	/// Composes [`FILE_MAP`](crate::co::FILE_MAP) (`u32`).
 	=>
@@ -140,6 +162,43 @@ pub_struct_const! { SECTION, u32,
 	ALL_ACCESS, STANDARD_RIGHTS::REQUIRED.0 | Self::QUERY.0 | Self::MAP_WRITE.0 | Self::MAP_EXECUTE.0 | Self::EXTEND_SIZE.0
 }
 
+pub_struct_const! { SHARD, u32,
+	/// [`SHARD`](https://docs.microsoft.com/en-us/windows/win32/api/shlobj_core/ne-shlobj_core-shard)
+	/// enumeration (`u32`).
+	=>
+	PIDL, 0x0000_0001
+	PATHA, 0x0000_0002
+	PATHW, 0x0000_0003
+	APPIDINFO, 0x0000_0004
+	APPIDINFOIDLIST, 0x0000_0005
+	LINK, 0x0000_0006
+	APPIDINFOLINK, 0x0000_0007
+	SHELLITEM, 0x0000_0008
+}
+
+pub_struct_const! { SHGFI, u32,
+	/// [`SHGetFileInfo`](crate::SHGetFileInfo) `uFlags` (`u32`).
+	=>
+	ICON, 0x0000_0100
+	DISPLAYNAME, 0x0000_0200
+	TYPENAME, 0x0000_0400
+	ATTRIBUTES, 0x0000_0800
+	ICONLOCATION, 0x0000_1000
+	EXETYPE, 0x0000_2000
+	SYSICONINDEX, 0x0000_4000
+	LINKOVERLAY, 0x0000_8000
+	SELECTED, 0x0001_0000
+	ATTR_SPECIFIED, 0x0002_0000
+	LARGEICON, 0x0000_0000
+	SMALLICON, 0x0000_0001
+	OPENICON, 0x0000_0002
+	SHELLICONSIZE, 0x0000_0004
+	PIDL, 0x0000_0008
+	USEFILEATTRIBUTES, 0x0000_0010
+	ADDOVERLAYS, 0x0000_0020
+	OVERLAYINDEX, 0x0000_0040
+}
+
 pub_struct_const! { SIF, u32,
 	/// [`SCROLLINFO`](crate::SCROLLINFO) `fMask` (`u32`).
 	=>
@@ -152,7 +211,7 @@ pub_struct_const! { SIF, u32,
 }
 
 pub_struct_const! { SIZE_R, u8,
-	/// [`WM_SIZE`](crate::msg::wm::Size) request (`u8`).
+	/// [`wm::Size`](crate::msg::wm::Size) request (`u8`).
 	=>
 	/// The window has been resized, but neither the `SIZE_R::MINIMIZED` nor
 	/// `SIZE_R::MAXIMIZED` value applies.
@@ -200,13 +259,25 @@ pub_struct_const! { SM, i32,
 	RESERVED2, 25
 	RESERVED3, 26
 	RESERVED4, 27
+	/// The minimum width of a window, in pixels.
 	CXMIN, 28
+	/// The minimum height of a window, in pixels.
 	CYMIN, 29
+	/// The width of a button in a window caption or title bar, in pixels.
 	CXSIZE, 30
+	/// The height of a button in a window caption or title bar, in pixels.
 	CYSIZE, 31
 	CXFRAME, 32
 	CYFRAME, 33
+	/// The minimum tracking width of a window, in pixels. The user cannot drag
+	/// the window frame to a size smaller than these dimensions. A window can
+	/// override this value by processing the
+	/// [`wm::GetMinMaxInfo`](crate::msg::wm::GetMinMaxInfo) message.
 	CXMINTRACK, 34
+	/// The minimum tracking height of a window, in pixels. The user cannot drag
+	/// the window frame to a size smaller than these dimensions. A window can
+	/// override this value by processing the
+	/// [`wm::GetMinMaxInfo`](crate::msg::wm::GetMinMaxInfo) message.
 	CYMINTRACK, 35
 	CXDOUBLECLK, 36
 	CYDOUBLECLK, 37
@@ -449,13 +520,14 @@ pub_struct_const! { SPI, u32,
 pub_struct_const! { SPIF, u32,
 	/// [`SystemParametersInfo`](crate::SystemParametersInfo) `fWinIni` (`u32`).
 	=>
-	ZERO, 0
+	/// None of the actual values (zero).
+	NoValue, 0
 	UPDATEINIFILE, 0x0001
 	SENDWININICHANGE, 0x0002
 	SENDCHANGE, Self::SENDWININICHANGE.0
 }
 
-pub_struct_const_ws! { SS,
+pub_struct_const_ws! { SS, u32,
 	/// Label control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/static-control-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
@@ -506,8 +578,8 @@ pub_struct_const! { STANDARD_RIGHTS, u32,
 }
 
 pub_struct_const! { STAP, u32,
-	/// [`GetThemeAppProperties`](crate::HTHEME::GetThemeAppProperties) return
-	/// value (`u32`).
+	/// [`HTHEME::GetThemeAppProperties`](crate::HTHEME::GetThemeAppProperties)
+	/// return value (`u32`).
 	=>
 	ALLOW_NONCLIENT, 1 << 0
 	ALLOW_CONTROLS, 1 << 1
@@ -516,9 +588,10 @@ pub_struct_const! { STAP, u32,
 }
 
 pub_struct_const! { STARTF, u32,
-	/// [`CreateProcess`](crate::HPROCESS::CreateProcess) `dwFlags` (`u32`).
+	/// [`HPROCESS::CreateProcess`](crate::HPROCESS::CreateProcess) `dwFlags`
+	/// (`u32`).
 	=>
-	FORCEONFEEDBACK , 0x0000_0040
+	FORCEONFEEDBACK, 0x0000_0040
 	FORCEOFFFEEDBACK, 0x0000_0080
 	PREVENTPINNING, 0x0000_2000
 	RUNFULLSCREEN, 0x0000_0020
@@ -535,10 +608,13 @@ pub_struct_const! { STARTF, u32,
 }
 
 pub_struct_const! { STATE_SYSTEM, u32,
-	/// [`DATETIMEPICKERINFO`](crate::DATETIMEPICKERINFO) `stateCheck` and
-	/// `stateButton`, [`TITLEBARINFOEX`](crate::TITLEBARINFOEX) `rgstate`
+	/// [`DATETIMEPICKERINFO`](crate::DATETIMEPICKERINFO) `stateCheck` and `stateButton`,
+	/// [`TITLEBARINFOEX`](crate::TITLEBARINFOEX) `rgstate`,
+	/// [`COMBOBOXINFO`](crate::COMBOBOXINFO) `stateButton`
 	/// (`u32`).
 	=>
+	/// None of the actual values (zero).
+	NoValue, 0
 	UNAVAILABLE, 0x0000_0001
 	SELECTED, 0x0000_0002
 	FOCUSED, 0x0000_0004
@@ -596,6 +672,40 @@ pub_struct_const_cmd! { STN,
 	DISABLE, 3
 }
 
+pub_struct_const! { STOCK_BRUSH, i32,
+	/// [`HBRUSH::GetStockObject`](crate::HBRUSH::GetStockObject) `i` (`i32`).
+	=>
+	BLACK, 4
+	DKGRAY, 3
+	DC, 18
+	GRAY, 2
+	HOLLOW, Self::NULL.0
+	LTGRAY, 1
+	NULL, 5
+	WHITE, 0
+}
+
+pub_struct_const! { STOCK_PEN, i32,
+	/// [`HPEN::GetStockObject`](crate::HPEN::GetStockObject) `i` (`i32`).
+	=>
+	BLACK, 7
+	DC, 19
+	NULL, 8
+	WHITE, 6
+}
+
+pub_struct_const! { STOCK_FONT, i32,
+	/// [`HFONT::GetStockObject`](crate::HFONT::GetStockObject) `i` (`i32`).
+	=>
+	ANSI_FIXED, 11
+	ANSI_VAR, 12
+	DEVICE_DEFAULT, 14
+	DEFAULT_GUI, 17
+	OEM_FIXED, 10
+	SYSTEM, 13
+	SYSTEM_FIXED, 16
+}
+
 pub_struct_const! { SUBLANG, u16,
 	/// Sublanguage
 	/// [identifier](https://docs.microsoft.com/en-us/windows/win32/intl/language-identifier-constants-and-strings)
@@ -848,7 +958,7 @@ pub_struct_const! { SUBLANG, u16,
 }
 
 pub_struct_const! { SW, i32,
-	/// [`ShowWindow`](crate::HWND::ShowWindow) `nCmdShow` (`i32`).
+	/// [`HWND::ShowWindow`](crate::HWND::ShowWindow) `nCmdShow` (`i32`).
 	=>
 	/// Hides the window and activates another window.
 	HIDE, 0
@@ -881,8 +991,8 @@ pub_struct_const! { SW, i32,
 	RESTORE, 9
 	/// Sets the show state based on the SW value specified in the
 	/// [`STARTUPINFO`](crate::STARTUPINFO) structure passed to the
-	/// [`CreateProcess`](crate::HPROCESS::CreateProcess) function by the
-	/// program that started the application.
+	/// [`HPROCESS::CreateProcess`](crate::HPROCESS::CreateProcess) function by
+	/// the program that started the application.
 	SHOWDEFAULT, 10
 	/// Minimizes a window, even if the thread that owns the window is not
 	/// responding. This flag should only be used when minimizing windows from a
@@ -891,7 +1001,7 @@ pub_struct_const! { SW, i32,
 }
 
 pub_struct_const! { SW_S, u8,
-	/// [`WM_SHOWWINDOW`](crate::msg::wm::ShowWindow) status (`u8`). Originally
+	/// [`wm::ShowWindow`](crate::msg::wm::ShowWindow) status (`u8`). Originally
 	/// has `SW` prefix.
 	=>
 	PARENTCLOSING, 1
@@ -901,7 +1011,7 @@ pub_struct_const! { SW_S, u8,
 }
 
 pub_struct_const! { SWP, u32,
-	/// [`SetWindowPos`](crate::HWND::SetWindowPos) `uFlags` (`u32`).
+	/// [`HWND::SetWindowPos`](crate::HWND::SetWindowPos) `uFlags` (`u32`).
 	=>
 	NOSIZE, 0x0001
 	NOMOVE, 0x0002
