@@ -1,8 +1,10 @@
+#![allow(non_camel_case_types, non_upper_case_globals)]
+
 use crate::co::{CCM, WM};
 
 pub_struct_const! { TA, u32,
-	/// [`SetTextAlign`](crate::HDC::SetTextAlign) `align` (`u32`). Also includes
-	/// constants with `VTA` prefix.
+	/// [`HDC::SetTextAlign`](crate::HDC::SetTextAlign) `align` (`u32`). Also
+	/// includes constants with `VTA` prefix.
 	=>
 	NOUPDATECP, 0
 	UPDATECP, 1
@@ -167,7 +169,7 @@ pub_struct_const_nm! { TBN,
 	WRAPHOTITEM, Self::FIRST.0 - 24
 }
 
-pub_struct_const_ws! { TBS,
+pub_struct_const_ws! { TBS, u32,
 	/// Trackbar control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/trackbar-control-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
@@ -191,11 +193,30 @@ pub_struct_const_ws! { TBS,
 	TRANSPARENTBKGND, 0x1000
 }
 
+pub_struct_const! { TBSTATE, u8,
+	/// Toolbar button
+	/// [states](https://docs.microsoft.com/en-us/windows/win32/controls/toolbar-button-states)
+	/// (`u8`).
+	=>
+	/// None of the actual values (zero).
+	NoValue, 0
+	CHECKED, 0x01
+	PRESSED, 0x02
+	ENABLED, 0x04
+	HIDDEN, 0x08
+	INDETERMINATE, 0x10
+	WRAP, 0x20
+	ELLIPSES, 0x40
+	MARKED, 0x80
+}
+
 pub_struct_const! { TCIS, u32,
 	/// Tab control item
 	/// [states](https://docs.microsoft.com/en-us/windows/win32/controls/tab-control-item-states)
 	/// (`u32`).
 	=>
+	/// None of the actual values (zero).
+	NoValue, 0
 	BUTTONPRESSED, 0x0001
 	HIGHLIGHTED, 0x0002
 }
@@ -252,7 +273,7 @@ pub_struct_const_nm! { TCN,
 	SELCHANGING, Self::FIRST.0 - 2
 }
 
-pub_struct_const_ws! { TCS,
+pub_struct_const_ws! { TCS, u32,
 	/// Tab control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/tab-control-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
@@ -289,8 +310,9 @@ pub_struct_const_wsex! { TCS_EX,
 }
 
 pub_struct_const! { TD_ICON, isize,
-	/// [`TaskDialog`](crate::HWND::TaskDialog) `pszIcon` (`isize`). Originally
-	/// has `TD` prefix and `ICON` suffix.
+	/// [`HWND::TaskDialog`](crate::HWND::TaskDialog) `pszIcon` and
+	/// [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `pszMainIcon` (`isize`).
+	/// Originally has `TD` prefix and `ICON` suffix.
 	=>
 	WARNING, -1
 	ERROR, -2
@@ -299,7 +321,8 @@ pub_struct_const! { TD_ICON, isize,
 }
 
 pub_struct_const! { TDCBF, i32,
-	/// [`TaskDialog`](crate::HWND::TaskDialog) `dwCommonButtons` (`i32`).
+	/// [`HWND::TaskDialog`](crate::HWND::TaskDialog) and
+	/// [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `dwCommonButtons` (`i32`).
 	/// Originally has `TDCBF` prefix and `BUTTON` suffix.
 	=>
 	OK, 0x0001
@@ -310,8 +333,32 @@ pub_struct_const! { TDCBF, i32,
 	CLOSE, 0x0020
 }
 
+pub_struct_const! { TDF, i32,
+	/// [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `dwFlags` (`i32`).
+	=>
+	ENABLE_HYPERLINKS, 0x0001
+	USE_HICON_MAIN, 0x0002
+	USE_HICON_FOOTER, 0x0004
+	ALLOW_DIALOG_CANCELLATION, 0x0008
+	USE_COMMAND_LINKS, 0x0010
+	USE_COMMAND_LINKS_NO_ICON, 0x0020
+	EXPAND_FOOTER_AREA, 0x0040
+	EXPANDED_BY_DEFAULT, 0x0080
+	VERIFICATION_FLAG_CHECKED, 0x0100
+	SHOW_PROGRESS_BAR, 0x0200
+	SHOW_MARQUEE_PROGRESS_BAR, 0x0400
+	CALLBACK_TIMER, 0x0800
+	POSITION_RELATIVE_TO_WINDOW, 0x1000
+	RTL_LAYOUT, 0x2000
+	NO_DEFAULT_RADIO_BUTTON, 0x4000
+	CAN_BE_MINIMIZED, 0x8000
+	NO_SET_FOREGROUND, 0x0001_0000
+	SIZE_TO_CONTENT, 0x0100_0000
+}
+
 pub_struct_const! { TH32CS, u32,
-	/// [`CreateToolhelp32Snapshot`](crate::HPROCESSLIST) `dwFlags` (`u32`).
+	/// [`HPROCESSLIST::CreateToolhelp32Snapshot`](crate::HPROCESSLIST)
+	/// `dwFlags` (`u32`).
 	=>
 	SNAPHEAPLIST, 0x0000_0001
 	SNAPPROCESS, 0x0000_0002
@@ -323,8 +370,8 @@ pub_struct_const! { TH32CS, u32,
 }
 
 pub_struct_const! { THREAD_CREATE, u32,
-	/// [`CreateThread`](crate::HTHREAD::CreateThread) `dwFlags` (`u32`).
-	/// Originally has no prefix.
+	/// [`HTHREAD::CreateThread`](crate::HTHREAD::CreateThread) `dwFlags`
+	/// (`u32`). Originally has no prefix.
 	=>
 	/// Originally just a zero.
 	RUN_IMMEDIATELY, 0
@@ -342,6 +389,268 @@ pub_struct_const! { TME, u32,
 	QUERY, 0x4000_0000
 }
 
+pub_struct_const! { TMT, i32,
+	/// Theme property
+	/// [identifiers](https://docs.microsoft.com/en-us/windows/win32/controls/property-typedefs)
+	/// (`i32`).
+	=>
+	DIBDATA, 2
+	GLYPHDIBDATA, 8
+	ENUM, 200
+	STRING, 201
+	INT, 202
+	BOOL, 203
+	COLOR, 204
+	MARGINS, 205
+	FILENAME, 206
+	SIZE, 207
+	POSITION, 208
+	RECT, 209
+	FONT, 210
+	INTLIST, 211
+	HBITMAP, 212
+	DISKSTREAM, 213
+	STREAM, 214
+	BITMAPREF, 215
+	FLOAT, 216
+	FLOATLIST, 217
+	COLORSCHEMES, 401
+	SIZES, 402
+	CHARSET, 403
+	NAME, 600
+	DISPLAYNAME, 601
+	TOOLTIP, 602
+	COMPANY, 603
+	AUTHOR, 604
+	COPYRIGHT, 605
+	URL, 606
+	VERSION, 607
+	DESCRIPTION, 608
+	FIRST_RCSTRING_NAME, Self::DISPLAYNAME.0
+	LAST_RCSTRING_NAME, Self::DESCRIPTION.0
+	CAPTIONFONT, 801
+	SMALLCAPTIONFONT, 802
+	MENUFONT, 803
+	STATUSFONT, 804
+	MSGBOXFONT, 805
+	ICONTITLEFONT, 806
+	HEADING1FONT, 807
+	HEADING2FONT, 808
+	BODYFONT, 809
+	FIRSTFONT, Self::CAPTIONFONT.0
+	LASTFONT, Self::BODYFONT.0
+	FLATMENUS, 1001
+	FIRSTBOOL, Self::FLATMENUS.0
+	LASTBOOL, Self::FLATMENUS.0
+	SIZINGBORDERWIDTH, 1201
+	SCROLLBARWIDTH, 1202
+	SCROLLBARHEIGHT, 1203
+	CAPTIONBARWIDTH, 1204
+	CAPTIONBARHEIGHT, 1205
+	SMCAPTIONBARWIDTH, 1206
+	SMCAPTIONBARHEIGHT, 1207
+	MENUBARWIDTH, 1208
+	MENUBARHEIGHT, 1209
+	PADDEDBORDERWIDTH, 1210
+	FIRSTSIZE, Self::SIZINGBORDERWIDTH.0
+	LASTSIZE, Self::PADDEDBORDERWIDTH.0
+	MINCOLORDEPTH, 1301
+	FIRSTINT, Self::MINCOLORDEPTH.0
+	LASTINT, Self::MINCOLORDEPTH.0
+	CSSNAME, 1401
+	XMLNAME, 1402
+	LASTUPDATED, 1403
+	ALIAS, 1404
+	FIRSTSTRING, Self::CSSNAME.0
+	LASTSTRING, Self::ALIAS.0
+	SCROLLBAR, 1601
+	BACKGROUND, 1602
+	ACTIVECAPTION, 1603
+	INACTIVECAPTION, 1604
+	MENU, 1605
+	WINDOW, 1606
+	WINDOWFRAME, 1607
+	MENUTEXT, 1608
+	WINDOWTEXT, 1609
+	CAPTIONTEXT, 1610
+	ACTIVEBORDER, 1611
+	INACTIVEBORDER, 1612
+	APPWORKSPACE, 1613
+	HIGHLIGHT, 1614
+	HIGHLIGHTTEXT, 1615
+	BTNFACE, 1616
+	BTNSHADOW, 1617
+	GRAYTEXT, 1618
+	BTNTEXT, 1619
+	INACTIVECAPTIONTEXT, 1620
+	BTNHIGHLIGHT, 1621
+	DKSHADOW3D, 1622
+	LIGHT3D, 1623
+	INFOTEXT, 1624
+	INFOBK, 1625
+	BUTTONALTERNATEFACE, 1626
+	HOTTRACKING, 1627
+	GRADIENTACTIVECAPTION, 1628
+	GRADIENTINACTIVECAPTION, 1629
+	MENUHILIGHT, 1630
+	MENUBAR, 1631
+	FIRSTCOLOR, Self::SCROLLBAR.0
+	LASTCOLOR, Self::MENUBAR.0
+	FROMHUE1, 1801
+	FROMHUE2, 1802
+	FROMHUE3, 1803
+	FROMHUE4, 1804
+	FROMHUE5, 1805
+	TOHUE1, 1806
+	TOHUE2, 1807
+	TOHUE3, 1808
+	TOHUE4, 1809
+	TOHUE5, 1810
+	FROMCOLOR1, 2001
+	FROMCOLOR2, 2002
+	FROMCOLOR3, 2003
+	FROMCOLOR4, 2004
+	FROMCOLOR5, 2005
+	TOCOLOR1, 2006
+	TOCOLOR2, 2007
+	TOCOLOR3, 2008
+	TOCOLOR4, 2009
+	TOCOLOR5, 2010
+	TRANSPARENT, 2201
+	AUTOSIZE, 2202
+	BORDERONLY, 2203
+	COMPOSITED, 2204
+	BGFILL, 2205
+	GLYPHTRANSPARENT, 2206
+	GLYPHONLY, 2207
+	ALWAYSSHOWSIZINGBAR, 2208
+	MIRRORIMAGE, 2209
+	UNIFORMSIZING, 2210
+	INTEGRALSIZING, 2211
+	SOURCEGROW, 2212
+	SOURCESHRINK, 2213
+	DRAWBORDERS, 2214
+	NOETCHEDEFFECT, 2215
+	TEXTAPPLYOVERLAY, 2216
+	TEXTGLOW, 2217
+	TEXTITALIC, 2218
+	COMPOSITEDOPAQUE, 2219
+	LOCALIZEDMIRRORIMAGE, 2220
+	IMAGECOUNT, 2401
+	ALPHALEVEL, 2402
+	BORDERSIZE, 2403
+	ROUNDCORNERWIDTH, 2404
+	ROUNDCORNERHEIGHT, 2405
+	GRADIENTRATIO1, 2406
+	GRADIENTRATIO2, 2407
+	GRADIENTRATIO3, 2408
+	GRADIENTRATIO4, 2409
+	GRADIENTRATIO5, 2410
+	PROGRESSCHUNKSIZE, 2411
+	PROGRESSSPACESIZE, 2412
+	SATURATION, 2413
+	TEXTBORDERSIZE, 2414
+	ALPHATHRESHOLD, 2415
+	WIDTH, 2416
+	HEIGHT, 2417
+	GLYPHINDEX, 2418
+	TRUESIZESTRETCHMARK, 2419
+	MINDPI1, 2420
+	MINDPI2, 2421
+	MINDPI3, 2422
+	MINDPI4, 2423
+	MINDPI5, 2424
+	TEXTGLOWSIZE, 2425
+	FRAMESPERSECOND, 2426
+	PIXELSPERFRAME, 2427
+	ANIMATIONDELAY, 2428
+	GLOWINTENSITY, 2429
+	OPACITY, 2430
+	COLORIZATIONCOLOR, 2431
+	COLORIZATIONOPACITY, 2432
+	MINDPI6, 2433
+	MINDPI7, 2434
+	GLYPHFONT, 2601
+	IMAGEFILE, 3001
+	IMAGEFILE1, 3002
+	IMAGEFILE2, 3003
+	IMAGEFILE3, 3004
+	IMAGEFILE4, 3005
+	IMAGEFILE5, 3006
+	GLYPHIMAGEFILE, 3008
+	IMAGEFILE6, 3009
+	IMAGEFILE7, 3010
+	TEXT, 3201
+	CLASSICVALUE, 3202
+	OFFSET, 3401
+	TEXTSHADOWOFFSET, 3402
+	MINSIZE, 3403
+	MINSIZE1, 3404
+	MINSIZE2, 3405
+	MINSIZE3, 3406
+	MINSIZE4, 3407
+	MINSIZE5, 3408
+	NORMALSIZE, 3409
+	MINSIZE6, 3410
+	MINSIZE7, 3411
+	SIZINGMARGINS, 3601
+	CONTENTMARGINS, 3602
+	CAPTIONMARGINS, 3603
+	BORDERCOLOR, 3801
+	FILLCOLOR, 3802
+	TEXTCOLOR, 3803
+	EDGELIGHTCOLOR, 3804
+	EDGEHIGHLIGHTCOLOR, 3805
+	EDGESHADOWCOLOR, 3806
+	EDGEDKSHADOWCOLOR, 3807
+	EDGEFILLCOLOR, 3808
+	TRANSPARENTCOLOR, 3809
+	GRADIENTCOLOR1, 3810
+	GRADIENTCOLOR2, 3811
+	GRADIENTCOLOR3, 3812
+	GRADIENTCOLOR4, 3813
+	GRADIENTCOLOR5, 3814
+	SHADOWCOLOR, 3815
+	GLOWCOLOR, 3816
+	TEXTBORDERCOLOR, 3817
+	TEXTSHADOWCOLOR, 3818
+	GLYPHTEXTCOLOR, 3819
+	GLYPHTRANSPARENTCOLOR, 3820
+	FILLCOLORHINT, 3821
+	BORDERCOLORHINT, 3822
+	ACCENTCOLORHINT, 3823
+	TEXTCOLORHINT, 3824
+	HEADING1TEXTCOLOR, 3825
+	HEADING2TEXTCOLOR, 3826
+	BODYTEXTCOLOR, 3827
+	BGTYPE, 4001
+	BORDERTYPE, 4002
+	FILLTYPE, 4003
+	SIZINGTYPE, 4004
+	HALIGN, 4005
+	CONTENTALIGNMENT, 4006
+	VALIGN, 4007
+	OFFSETTYPE, 4008
+	ICONEFFECT, 4009
+	TEXTSHADOWTYPE, 4010
+	IMAGELAYOUT, 4011
+	GLYPHTYPE, 4012
+	IMAGESELECTTYPE, 4013
+	GLYPHFONTSIZINGTYPE, 4014
+	TRUESIZESCALINGTYPE, 4015
+	USERPICTURE, 5001
+	DEFAULTPANESIZE, 5002
+	BLENDCOLOR, 5003
+	CUSTOMSPLITRECT, 5004
+	ANIMATIONBUTTONRECT, 5005
+	ANIMATIONDURATION, 5006
+	TRANSITIONDURATIONS, 6000
+	SCALEDBACKGROUND, 7001
+	ATLASIMAGE, 8000
+	ATLASINPUTIMAGE, 8001
+	ATLASRECT, 8002
+}
+
 pub_struct_const! { TPM, u32,
 	/// [`TrackPopupMenu`](crate::HMENU::TrackPopupMenu) `uFlags` (`u32`).
 	=>
@@ -423,7 +732,7 @@ pub_struct_const_nm! { TRBN,
 }
 
 pub_struct_const! { TVE, u32,
-	/// [`TVM_EXPAND`](crate::msg::tvm::Expand) `action` (`u32`).
+	/// [`tvm::Expand`](crate::msg::tvm::Expand) `action` (`u32`).
 	=>
 	COLLAPSE, 0x0001
 	EXPAND, 0x0002
@@ -433,7 +742,7 @@ pub_struct_const! { TVE, u32,
 }
 
 pub_struct_const! { TVGN, u32,
-	/// [`TVM_GETNEXTITEM`](crate::msg::tvm::GetNextItem) `which` (`u32`).
+	/// [`tvm::GetNextItem`](crate::msg::tvm::GetNextItem) `which` (`u32`).
 	=>
 	ROOT, 0x0000
 	NEXT, 0x0001
@@ -480,6 +789,8 @@ pub_struct_const! { TVIS, u32,
 	/// [states](https://docs.microsoft.com/en-us/windows/win32/controls/tree-view-control-item-states)
 	/// (`u32`)
 	=>
+	/// None of the actual values (zero).
+	NoValue, 0
 	SELECTED, 0x0002
 	CUT, 0x0004
 	DROPHILITED, 0x0008
@@ -587,7 +898,7 @@ pub_struct_const_nm! { TVN,
 	ASYNCDRAW, Self::FIRST.0 - 20
 }
 
-pub_struct_const_ws! { TVS,
+pub_struct_const_ws! { TVS, u32,
 	/// Tree view control
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/tree-view-control-window-styles)
 	/// (`u32`), convertible to [`WS`](crate::co::WS).
@@ -615,7 +926,8 @@ pub_struct_const_wsex! { TVS_EX,
 	/// [styles](https://docs.microsoft.com/en-us/windows/win32/controls/tree-view-control-window-extended-styles)
 	/// (`u32`), convertible to [`WS_EX`](crate::co::WS_EX).
 	=>
-	NONE, 0
+	/// None of the actual values (zero).
+	NoValue, 0
 	NOSINGLECOLLAPSE, 0x0001
 	MULTISELECT, 0x0002
 	DOUBLEBUFFER, 0x0004
@@ -628,3 +940,11 @@ pub_struct_const_wsex! { TVS_EX,
 	DIMMEDCHECKBOXES, 0x0200
 	DRAWIMAGEASYNC, 0x0400
 }
+
+pub_struct_const! { TVSIL, u8,
+	/// [`tvm::GetImageList`](crate::msg::tvm::GetImageList) and
+	/// [`tvm::SetImageList`](crate::msg::tvm::SetImageList) `kind`.
+	=>
+	NORMAL, 0
+	STATE, 2
+}
