@@ -5,7 +5,7 @@ use crate::ffi::kernel32;
 use crate::funcs::GetLastError;
 use crate::handles::HLOCAL;
 use crate::structs::LANGID;
-use crate::WString;
+use crate::various::WString;
 
 pub_struct_const_no_debug_display! { ERROR, u32,
 	/// A Windows
@@ -22,8 +22,8 @@ pub_struct_const_no_debug_display! { ERROR, u32,
 	/// [`Debug`](https://doc.rust-lang.org/std/fmt/trait.Debug.html) and
 	/// [`Display`](https://doc.rust-lang.org/std/fmt/trait.Display.html) traits
 	/// to show the error code along with the error description, taken from
-	/// [`FormatMessage`](crate::co::ERROR::FormatMessage). For example, the code
-	/// below:
+	/// [`ERROR::FormatMessage`](crate::co::ERROR::FormatMessage). For example,
+	/// the code below:
 	///
 	/// ```rust,ignore
 	/// use winsafe::co::ERROR;
@@ -2644,187 +2644,155 @@ pub_struct_const_no_debug_display! { ERROR, u32,
 	STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED, 15818
 	API_UNAVAILABLE, 15841
 
-	CDERR_DIALOGFAILURE, 0xffff
-	CDERR_FINDRESFAILURE, 0x0006
-	CDERR_INITIALIZATION, 0x0002
-	CDERR_LOADRESFAILURE, 0x0007
-	CDERR_LOADSTRFAILURE, 0x0005
-	CDERR_LOCKRESFAILURE, 0x0008
-	CDERR_MEMALLOCFAILURE, 0x0009
-	CDERR_MEMLOCKFAILURE, 0x000a
-	CDERR_NOHINSTANCE, 0x0004
-	CDERR_NOHOOK, 0x000b
-	CDERR_NOTEMPLATE, 0x0003
-	CDERR_REGISTERMSGFAIL, 0x000c
-	CDERR_STRUCTSIZE, 0x0001
-	PDERR_CREATEICFAILURE, 0x100a
-	PDERR_DEFAULTDIFFERENT, 0x100c
-	PDERR_DNDMMISMATCH, 0x1009
-	PDERR_GETDEVMODEFAIL, 0x1005
-	PDERR_INITFAILURE, 0x1006
-	PDERR_LOADDRVFAILURE, 0x1004
-	PDERR_NODEFAULTPRN, 0x1008
-	PDERR_NODEVICES, 0x1007
-	PDERR_PARSEFAILURE, 0x1002
-	PDERR_PRINTERNOTFOUND, 0x100b
-	PDERR_RETDEFFAILURE, 0x1003
-	PDERR_SETUPFAILURE, 0x1001
-	CFERR_MAXLESSTHANMIN, 0x2002
-	CFERR_NOFONTS, 0x2001
-	FNERR_BUFFERTOOSMALL, 0x3003
-	FNERR_INVALIDFILENAME, 0x3002
-	FNERR_SUBCLASSFAILURE, 0x3001
-	FRERR_BUFFERLENGTHZERO, 0x4001
-
 	/// Operation successful.
 	S_OK, 0
 	S_FALSE, 1
 
-	E_UNEXPECTED, 0x8000ffff
-	E_NOTIMPL, 0x80004001
-	E_OUTOFMEMORY, 0x8007000e
-	E_INVALIDARG, 0x80070057
-	E_NOINTERFACE, 0x80004002
-	E_POINTER, 0x80004003
-	E_HANDLE, 0x80070006
-	E_ABORT, 0x80004004
-	E_FAIL, 0x80004005
-	E_ACCESSDENIED, 0x80070005
-	E_PENDING, 0x8000000a
-	E_BOUNDS, 0x8000000b
-	E_CHANGED_STATE, 0x8000000c
-	E_ILLEGAL_STATE_CHANGE, 0x8000000d
-	E_ILLEGAL_METHOD_CALL, 0x8000000e
+	E_UNEXPECTED, 0x8000_ffff
+	E_NOTIMPL, 0x8000_4001
+	E_OUTOFMEMORY, 0x8007_000e
+	E_INVALIDARG, 0x8007_0057
+	E_NOINTERFACE, 0x8000_4002
+	E_POINTER, 0x8000_4003
+	E_HANDLE, 0x8007_0006
+	E_ABORT, 0x8000_4004
+	E_FAIL, 0x8000_4005
+	E_ACCESSDENIED, 0x8007_0005
+	E_PENDING, 0x8000_000a
+	E_BOUNDS, 0x8000_000b
+	E_CHANGED_STATE, 0x8000_000c
+	E_ILLEGAL_STATE_CHANGE, 0x8000_000d
+	E_ILLEGAL_METHOD_CALL, 0x8000_000e
 
-	RPC_E_CALL_REJECTED, 0x80010001
-	RPC_E_CALL_CANCELED, 0x80010002
-	RPC_E_CANTPOST_INSENDCALL, 0x80010003
-	RPC_E_CANTCALLOUT_INASYNCCALL, 0x80010004
-	RPC_E_CANTCALLOUT_INEXTERNALCALL, 0x80010005
-	RPC_E_CONNECTION_TERMINATED, 0x80010006
-	RPC_E_SERVER_DIED, 0x80010007
-	RPC_E_CLIENT_DIED, 0x80010008
-	RPC_E_INVALID_DATAPACKET, 0x80010009
-	RPC_E_CANTTRANSMIT_CALL, 0x8001000a
-	RPC_E_CLIENT_CANTMARSHAL_DATA, 0x8001000b
-	RPC_E_CLIENT_CANTUNMARSHAL_DATA, 0x8001000c
-	RPC_E_SERVER_CANTMARSHAL_DATA, 0x8001000d
-	RPC_E_SERVER_CANTUNMARSHAL_DATA, 0x8001000e
-	RPC_E_INVALID_DATA, 0x8001000f
-	RPC_E_INVALID_PARAMETER, 0x80010010
-	RPC_E_CANTCALLOUT_AGAIN, 0x80010011
-	RPC_E_SERVER_DIED_DNE, 0x80010012
-	RPC_E_SYS_CALL_FAILED, 0x80010100
-	RPC_E_OUT_OF_RESOURCES, 0x80010101
-	RPC_E_ATTEMPTED_MULTITHREAD, 0x80010102
-	RPC_E_NOT_REGISTERED, 0x80010103
-	RPC_E_FAULT, 0x80010104
-	RPC_E_SERVERFAULT, 0x80010105
-	RPC_E_CHANGED_MODE, 0x80010106
-	RPC_E_INVALIDMETHOD, 0x80010107
-	RPC_E_DISCONNECTED, 0x80010108
-	RPC_E_RETRY, 0x80010109
-	RPC_E_SERVERCALL_RETRYLATER, 0x8001010a
-	RPC_E_SERVERCALL_REJECTED, 0x8001010b
-	RPC_E_INVALID_CALLDATA, 0x8001010c
-	RPC_E_CANTCALLOUT_ININPUTSYNCCALL, 0x8001010d
-	RPC_E_WRONG_THREAD, 0x8001010e
-	RPC_E_THREAD_NOT_INIT, 0x8001010f
-	RPC_E_VERSION_MISMATCH, 0x80010110
-	RPC_E_INVALID_HEADER, 0x80010111
-	RPC_E_INVALID_EXTENSION, 0x80010112
-	RPC_E_INVALID_IPID, 0x80010113
-	RPC_E_INVALID_OBJECT, 0x80010114
-	RPC_E_CALL_COMPLETE, 0x80010117
-	RPC_E_UNSECURE_CALL, 0x80010118
-	RPC_E_TOO_LATE, 0x80010119
-	RPC_E_NO_GOOD_SECURITY_PACKAGES, 0x8001011a
-	RPC_E_ACCESS_DENIED, 0x8001011b
-	RPC_E_REMOTE_DISABLED, 0x8001011c
-	RPC_E_INVALID_OBJREF, 0x8001011d
-	RPC_E_NO_CONTEXT, 0x8001011e
-	RPC_E_TIMEOUT, 0x8001011f
-	RPC_E_NO_SYNC, 0x80010120
-	RPC_E_FULLSIC_REQUIRED, 0x80010121
-	RPC_E_INVALID_STD_NAME, 0x80010122
-	RPC_E_UNEXPECTED, 0x8001ffff
+	RPC_E_CALL_REJECTED, 0x8001_0001
+	RPC_E_CALL_CANCELED, 0x8001_0002
+	RPC_E_CANTPOST_INSENDCALL, 0x8001_0003
+	RPC_E_CANTCALLOUT_INASYNCCALL, 0x8001_0004
+	RPC_E_CANTCALLOUT_INEXTERNALCALL, 0x8001_0005
+	RPC_E_CONNECTION_TERMINATED, 0x8001_0006
+	RPC_E_SERVER_DIED, 0x8001_0007
+	RPC_E_CLIENT_DIED, 0x8001_0008
+	RPC_E_INVALID_DATAPACKET, 0x8001_0009
+	RPC_E_CANTTRANSMIT_CALL, 0x8001_000a
+	RPC_E_CLIENT_CANTMARSHAL_DATA, 0x8001_000b
+	RPC_E_CLIENT_CANTUNMARSHAL_DATA, 0x8001_000c
+	RPC_E_SERVER_CANTMARSHAL_DATA, 0x8001_000d
+	RPC_E_SERVER_CANTUNMARSHAL_DATA, 0x8001_000e
+	RPC_E_INVALID_DATA, 0x8001_000f
+	RPC_E_INVALID_PARAMETER, 0x8001_0010
+	RPC_E_CANTCALLOUT_AGAIN, 0x8001_0011
+	RPC_E_SERVER_DIED_DNE, 0x8001_0012
+	RPC_E_SYS_CALL_FAILED, 0x8001_0100
+	RPC_E_OUT_OF_RESOURCES, 0x8001_0101
+	RPC_E_ATTEMPTED_MULTITHREAD, 0x8001_0102
+	RPC_E_NOT_REGISTERED, 0x8001_0103
+	RPC_E_FAULT, 0x8001_0104
+	RPC_E_SERVERFAULT, 0x8001_0105
+	RPC_E_CHANGED_MODE, 0x8001_0106
+	RPC_E_INVALIDMETHOD, 0x8001_0107
+	RPC_E_DISCONNECTED, 0x8001_0108
+	RPC_E_RETRY, 0x8001_0109
+	RPC_E_SERVERCALL_RETRYLATER, 0x8001_010a
+	RPC_E_SERVERCALL_REJECTED, 0x8001_010b
+	RPC_E_INVALID_CALLDATA, 0x8001_010c
+	RPC_E_CANTCALLOUT_ININPUTSYNCCALL, 0x8001_010d
+	RPC_E_WRONG_THREAD, 0x8001_010e
+	RPC_E_THREAD_NOT_INIT, 0x8001_010f
+	RPC_E_VERSION_MISMATCH, 0x8001_0110
+	RPC_E_INVALID_HEADER, 0x8001_0111
+	RPC_E_INVALID_EXTENSION, 0x8001_0112
+	RPC_E_INVALID_IPID, 0x8001_0113
+	RPC_E_INVALID_OBJECT, 0x8001_0114
+	RPC_E_CALL_COMPLETE, 0x8001_0117
+	RPC_E_UNSECURE_CALL, 0x8001_0118
+	RPC_E_TOO_LATE, 0x8001_0119
+	RPC_E_NO_GOOD_SECURITY_PACKAGES, 0x8001_011a
+	RPC_E_ACCESS_DENIED, 0x8001_011b
+	RPC_E_REMOTE_DISABLED, 0x8001_011c
+	RPC_E_INVALID_OBJREF, 0x8001_011d
+	RPC_E_NO_CONTEXT, 0x8001_011e
+	RPC_E_TIMEOUT, 0x8001_011f
+	RPC_E_NO_SYNC, 0x8001_0120
+	RPC_E_FULLSIC_REQUIRED, 0x8001_0121
+	RPC_E_INVALID_STD_NAME, 0x8001_0122
+	RPC_E_UNEXPECTED, 0x8001_ffff
 
-	CO_E_NOTINITIALIZED, 0x800401f0
-	CO_E_ALREADYINITIALIZED, 0x800401f1
-	CO_E_CANTDETERMINECLASS, 0x800401f2
-	CO_E_CLASSSTRING, 0x800401f3
-	CO_E_IIDSTRING, 0x800401f4
-	CO_E_APPNOTFOUND, 0x800401f5
-	CO_E_APPSINGLEUSE, 0x800401f6
-	CO_E_ERRORINAPP, 0x800401f7
-	CO_E_DLLNOTFOUND, 0x800401f8
-	CO_E_ERRORINDLL, 0x800401f9
-	CO_E_WRONGOSFORAPP, 0x800401fa
-	CO_E_OBJNOTREG, 0x800401fb
-	CO_E_OBJISREG, 0x800401fc
-	CO_E_OBJNOTCONNECTED, 0x800401fd
-	CO_E_APPDIDNTREG, 0x800401fe
-	CO_E_RELEASED, 0x800401ff
+	CO_E_NOTINITIALIZED, 0x8004_01f0
+	CO_E_ALREADYINITIALIZED, 0x8004_01f1
+	CO_E_CANTDETERMINECLASS, 0x8004_01f2
+	CO_E_CLASSSTRING, 0x8004_01f3
+	CO_E_IIDSTRING, 0x8004_01f4
+	CO_E_APPNOTFOUND, 0x8004_01f5
+	CO_E_APPSINGLEUSE, 0x8004_01f6
+	CO_E_ERRORINAPP, 0x8004_01f7
+	CO_E_DLLNOTFOUND, 0x8004_01f8
+	CO_E_ERRORINDLL, 0x8004_01f9
+	CO_E_WRONGOSFORAPP, 0x8004_01fa
+	CO_E_OBJNOTREG, 0x8004_01fb
+	CO_E_OBJISREG, 0x8004_01fc
+	CO_E_OBJNOTCONNECTED, 0x8004_01fd
+	CO_E_APPDIDNTREG, 0x8004_01fe
+	CO_E_RELEASED, 0x8004_01ff
 
-	MF_E_PLATFORM_NOT_INITIALIZED, 0xc00d36b0
-	MF_E_BUFFERTOOSMALL, 0xc00d36b1
-	MF_E_INVALIDREQUEST, 0xc00d36b2
-	MF_E_INVALIDSTREAMNUMBER, 0xc00d36b3
-	MF_E_INVALIDMEDIATYPE, 0xc00d36b4
-	MF_E_NOTACCEPTING, 0xc00d36b5
-	MF_E_NOT_INITIALIZED, 0xc00d36b6
-	MF_E_UNSUPPORTED_REPRESENTATION, 0xc00d36b7
-	MF_E_NO_MORE_TYPES, 0xc00d36b9
-	MF_E_UNSUPPORTED_SERVICE, 0xc00d36ba
-	MF_E_UNEXPECTED, 0xc00d36bb
-	MF_E_INVALIDNAME, 0xc00d36bc
-	MF_E_INVALIDTYPE, 0xc00d36bd
-	MF_E_INVALID_FILE_FORMAT, 0xc00d36be
-	MF_E_INVALIDINDEX, 0xc00d36bf
-	MF_E_INVALID_TIMESTAMP, 0xc00d36c0
-	MF_E_UNSUPPORTED_SCHEME, 0xc00d36c3
-	MF_E_UNSUPPORTED_BYTESTREAM_TYPE, 0xc00d36c4
-	MF_E_UNSUPPORTED_TIME_FORMAT, 0xc00d36c5
-	MF_E_NO_SAMPLE_TIMESTAMP, 0xc00d36c8
-	MF_E_NO_SAMPLE_DURATION, 0xc00d36c9
-	MF_E_INVALID_STREAM_DATA, 0xc00d36cb
-	MF_E_RT_UNAVAILABLE, 0xc00d36cf
-	MF_E_UNSUPPORTED_RATE, 0xc00d36d0
-	MF_E_THINNING_UNSUPPORTED, 0xc00d36d1
-	MF_E_REVERSE_UNSUPPORTED, 0xc00d36d2
-	MF_E_UNSUPPORTED_RATE_TRANSITION, 0xc00d36d3
-	MF_E_RATE_CHANGE_PREEMPTED, 0xc00d36d4
-	MF_E_NOT_FOUND, 0xc00d36d5
-	MF_E_NOT_AVAILABLE, 0xc00d36d6
-	MF_E_NO_CLOCK, 0xc00d36d7
-	MF_S_MULTIPLE_BEGIN, 0x000d36d8
-	MF_E_MULTIPLE_BEGIN, 0xc00d36d9
-	MF_E_MULTIPLE_SUBSCRIBERS, 0xc00d36da
-	MF_E_TIMER_ORPHANED, 0xc00d36db
-	MF_E_STATE_TRANSITION_PENDING, 0xc00d36dc
-	MF_E_UNSUPPORTED_STATE_TRANSITION, 0xc00d36dd
-	MF_E_UNRECOVERABLE_ERROR_OCCURRED, 0xc00d36de
-	MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS, 0xc00d36df
-	MF_E_SAMPLE_NOT_WRITABLE, 0xc00d36e0
-	MF_E_INVALID_KEY, 0xc00d36e2
-	MF_E_BAD_STARTUP_VERSION, 0xc00d36e3
-	MF_E_UNSUPPORTED_CAPTION, 0xc00d36e4
-	MF_E_INVALID_POSITION, 0xc00d36e5
-	MF_E_ATTRIBUTENOTFOUND, 0xc00d36e6
-	MF_E_PROPERTY_TYPE_NOT_ALLOWED, 0xc00d36e7
-	MF_E_TOPO_INVALID_OPTIONAL_NODE, 0xc00d520e
-	MF_E_TOPO_CANNOT_FIND_DECRYPTOR, 0xc00d5211
-	MF_E_TOPO_CODEC_NOT_FOUND, 0xc00d5212
-	MF_E_TOPO_CANNOT_CONNECT, 0xc00d5213
-	MF_E_TOPO_UNSUPPORTED, 0xc00d5214
-	MF_E_TOPO_INVALID_TIME_ATTRIBUTES, 0xc00d5215
-	MF_E_TOPO_LOOPS_IN_TOPOLOGY, 0xC00d5216
-	MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR, 0xc00d5217
-	MF_E_TOPO_MISSING_STREAM_DESCRIPTOR, 0xc00d5218
-	MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED, 0xc00d5219
-	MF_E_TOPO_MISSING_SOURCE, 0xc00d521a
-	MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED, 0xc00d521b
-	MF_E_TRANSFORM_TYPE_NOT_SET, 0xc00d6d60
+	MF_E_PLATFORM_NOT_INITIALIZED, 0xc00d_36b0
+	MF_E_BUFFERTOOSMALL, 0xc00d_36b1
+	MF_E_INVALIDREQUEST, 0xc00d_36b2
+	MF_E_INVALIDSTREAMNUMBER, 0xc00d_36b3
+	MF_E_INVALIDMEDIATYPE, 0xc00d_36b4
+	MF_E_NOTACCEPTING, 0xc00d_36b5
+	MF_E_NOT_INITIALIZED, 0xc00d_36b6
+	MF_E_UNSUPPORTED_REPRESENTATION, 0xc00d_36b7
+	MF_E_NO_MORE_TYPES, 0xc00d_36b9
+	MF_E_UNSUPPORTED_SERVICE, 0xc00d_36ba
+	MF_E_UNEXPECTED, 0xc00d_36bb
+	MF_E_INVALIDNAME, 0xc00d_36bc
+	MF_E_INVALIDTYPE, 0xc00d_36bd
+	MF_E_INVALID_FILE_FORMAT, 0xc00d_36be
+	MF_E_INVALIDINDEX, 0xc00d_36bf
+	MF_E_INVALID_TIMESTAMP, 0xc00d_36c0
+	MF_E_UNSUPPORTED_SCHEME, 0xc00d_36c3
+	MF_E_UNSUPPORTED_BYTESTREAM_TYPE, 0xc00d_36c4
+	MF_E_UNSUPPORTED_TIME_FORMAT, 0xc00d_36c5
+	MF_E_NO_SAMPLE_TIMESTAMP, 0xc00d_36c8
+	MF_E_NO_SAMPLE_DURATION, 0xc00d_36c9
+	MF_E_INVALID_STREAM_DATA, 0xc00d_36cb
+	MF_E_RT_UNAVAILABLE, 0xc00d_36cf
+	MF_E_UNSUPPORTED_RATE, 0xc00d_36d0
+	MF_E_THINNING_UNSUPPORTED, 0xc00d_36d1
+	MF_E_REVERSE_UNSUPPORTED, 0xc00d_36d2
+	MF_E_UNSUPPORTED_RATE_TRANSITION, 0xc00d_36d3
+	MF_E_RATE_CHANGE_PREEMPTED, 0xc00d_36d4
+	MF_E_NOT_FOUND, 0xc00d_36d5
+	MF_E_NOT_AVAILABLE, 0xc00d_36d6
+	MF_E_NO_CLOCK, 0xc00d_36d7
+	MF_S_MULTIPLE_BEGIN, 0x000d_36d8
+	MF_E_MULTIPLE_BEGIN, 0xc00d_36d9
+	MF_E_MULTIPLE_SUBSCRIBERS, 0xc00d_36da
+	MF_E_TIMER_ORPHANED, 0xc00d_36db
+	MF_E_STATE_TRANSITION_PENDING, 0xc00d_36dc
+	MF_E_UNSUPPORTED_STATE_TRANSITION, 0xc00d_36dd
+	MF_E_UNRECOVERABLE_ERROR_OCCURRED, 0xc00d_36de
+	MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS, 0xc00d_36df
+	MF_E_SAMPLE_NOT_WRITABLE, 0xc00d_36e0
+	MF_E_INVALID_KEY, 0xc00d_36e2
+	MF_E_BAD_STARTUP_VERSION, 0xc00d_36e3
+	MF_E_UNSUPPORTED_CAPTION, 0xc00d_36e4
+	MF_E_INVALID_POSITION, 0xc00d_36e5
+	MF_E_ATTRIBUTENOTFOUND, 0xc00d_36e6
+	MF_E_PROPERTY_TYPE_NOT_ALLOWED, 0xc00d_36e7
+	MF_E_TOPO_INVALID_OPTIONAL_NODE, 0xc00d_520e
+	MF_E_TOPO_CANNOT_FIND_DECRYPTOR, 0xc00d_5211
+	MF_E_TOPO_CODEC_NOT_FOUND, 0xc00d_5212
+	MF_E_TOPO_CANNOT_CONNECT, 0xc00d_5213
+	MF_E_TOPO_UNSUPPORTED, 0xc00d_5214
+	MF_E_TOPO_INVALID_TIME_ATTRIBUTES, 0xc00d_5215
+	MF_E_TOPO_LOOPS_IN_TOPOLOGY, 0xC00d_5216
+	MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR, 0xc00d_5217
+	MF_E_TOPO_MISSING_STREAM_DESCRIPTOR, 0xc00d_5218
+	MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED, 0xc00d_5219
+	MF_E_TOPO_MISSING_SOURCE, 0xc00d_521a
+	MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED, 0xc00d_521b
+	MF_E_TRANSFORM_TYPE_NOT_SET, 0xc00d_6d60
 }
 
 impl std::error::Error for ERROR {
