@@ -6,10 +6,9 @@
 #[macro_use]
 mod macros;
 
-mod com_dshow;
-mod com_shell;
 mod consts_ab;
-mod consts_cd;
+mod consts_c;
+mod consts_d;
 mod consts_ef;
 mod consts_ghij;
 mod consts_kl;
@@ -20,11 +19,11 @@ mod consts_t;
 mod consts_uv;
 mod consts_wxyz;
 mod error;
+mod vs;
 
-pub use com_dshow::*;
-pub use com_shell::*;
 pub use consts_ab::*;
-pub use consts_cd::*;
+pub use consts_c::*;
+pub use consts_d::*;
 pub use consts_ef::*;
 pub use consts_ghij::*;
 pub use consts_kl::*;
@@ -35,3 +34,4 @@ pub use consts_t::*;
 pub use consts_uv::*;
 pub use consts_wxyz::*;
 pub use error::ERROR;
+pub use vs::VS;
