@@ -10,9 +10,12 @@ extern "system" {
 	pub fn GetThemeBackgroundContentRect(_: HANDLE, _: HANDLE, _: i32, _: i32, _: PCVOID, _: PVOID) -> HRESULT;
 	pub fn GetThemeBackgroundExtent(_: HANDLE, _: HANDLE, _: i32, _: i32, _: PCVOID, _: PVOID) -> HRESULT;
 	pub fn GetThemeBackgroundRegion(_: HANDLE, _: HANDLE, _: i32, _: i32, _: PCVOID, _: PVOID) -> HRESULT;
+	pub fn GetThemeColor(_: HANDLE, _: i32, _: i32, _: i32, _: *mut u32) -> HRESULT;
 	pub fn IsAppThemed() -> BOOL;
 	pub fn IsCompositionActive() -> BOOL;
 	pub fn IsThemeActive() -> BOOL;
+	pub fn IsThemeBackgroundPartiallyTransparent(_: HANDLE, _: i32, _: i32) -> BOOL;
 	pub fn IsThemeDialogTextureEnabled() -> BOOL;
+	pub fn IsThemePartDefined(_: HANDLE, _: i32, _: i32) -> BOOL;
 	pub fn OpenThemeData(_: HANDLE, _: PCSTR) -> HANDLE;
 }
