@@ -6,30 +6,52 @@ use std::collections::HashMap;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::ffi::{advapi32, BOOL, comctl32, comdlg32, HRESULT, kernel32, user32};
-use crate::handles::{HINSTANCE, HWND};
+use crate::ffi::{
+	advapi32,
+	BOOL,
+	comctl32,
+	comdlg32,
+	HRESULT,
+	kernel32,
+	shell32,
+	user32,
+	version,
+};
+use crate::handles::{HINSTANCE, HLOCAL, HWND};
 use crate::privs::{
 	bool_to_winresult,
+	hr_to_winresult,
 	INVALID_FILE_ATTRIBUTES,
+	MAX_COMPUTERNAME_LENGTH,
 	MAX_PATH,
 	parse_multi_z_str,
+	UNLEN,
 };
 use crate::structs::{
 	ATOM,
 	CHOOSECOLOR,
 	COLORREF,
+	DEVMODE,
 	FILETIME,
+	GUITHREADINFO,
 	MEMORYSTATUSEX,
 	MSG,
+	NOTIFYICONDATA,
 	OSVERSIONINFOEX,
 	POINT,
 	RECT,
+	SHFILEINFO,
+	SHFILEOPSTRUCT,
+	SIZE,
+	STARTUPINFO,
+	SYSTEM_INFO,
 	SYSTEMTIME,
+	TASKDIALOGCONFIG,
 	TIME_ZONE_INFORMATION,
 	TRACKMOUSEEVENT,
 	WNDCLASSEX,
 };
-use crate::WString;
+use crate::various::WString;
 
 /// [`AdjustWindowRectEx`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-adjustwindowrectex)
 /// function.
@@ -49,6 +71,22 @@ pub fn AdjustWindowRectEx(
 	)
 }
 
+/// [`ChangeDisplaySettings`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-changedisplaysettingsw)
+/// function.
+pub fn ChangeDisplaySettings(
+	lpDevMode: &mut DEVMODE,
+	dwFlags: co::CDS) -> Result<co::DISP_CHANGE, co::DISP_CHANGE>
+{
+	let ret = unsafe {
+		user32::ChangeDisplaySettingsW(lpDevMode as *mut _ as _, dwFlags.0)
+	};
+	if ret < 0 {
+		Err(co::DISP_CHANGE(ret))
+	} else {
+		Ok(co::DISP_CHANGE(ret))
+	}
+}
+
 /// [`ChooseColor`](https://docs.microsoft.com/en-us/previous-versions/windows/desktop/legacy/ms646912(v=vs.85))
 /// function.
 ///
@@ -75,10 +113,10 @@ pub fn AdjustWindowRectEx(
 ///     );
 /// }
 /// ```
-pub fn ChooseColor(lpcc: &mut CHOOSECOLOR) -> WinResult<bool> {
+pub fn ChooseColor(lpcc: &mut CHOOSECOLOR) -> Result<bool, co::CDERR> {
 	match unsafe { comdlg32::ChooseColorW(lpcc as *mut _ as _) } {
 		0 => match CommDlgExtendedError() {
-			co::ERROR::SUCCESS => Ok(false),
+			co::CDERR::NoValue => Ok(false),
 			err => Err(err),
 		},
 		_ => Ok(true),
@@ -86,7 +124,7 @@ pub fn ChooseColor(lpcc: &mut CHOOSECOLOR) -> WinResult<bool> {
 }
 
 /// [`ClipCursor`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-clipcursor)
-/// method.
+/// function.
 pub fn ClipCursor(lpRect: Option<&RECT>) -> WinResult<()> {
 	bool_to_winresult(
 		unsafe {
@@ -103,19 +141,45 @@ pub fn CloseClipboard() -> WinResult<()> {
 	bool_to_winresult(unsafe { user32::CloseClipboard() })
 }
 
-/// [`CommDlgExtendedError`](https://docs.microsoft.com/en-us/windows/win32/api/commdlg/nf-commdlg-commdlgextendederror)
+/// [`CommandLineToArgv`](https://docs.microsoft.com/en-us/windows/win32/api/shellapi/nf-shellapi-commandlinetoargvw)
 /// function.
 ///
-/// **Note:** The [`co::ERROR`](crate::co::ERROR) returned by this function
-/// cannot be properly formatted by
-/// [`Debug`](https://doc.rust-lang.org/std/fmt/trait.Debug.html) and
-/// [`Display`](https://doc.rust-lang.org/std/fmt/trait.Display.html) traits,
-/// thus showing a wrong description. The formatted text actually will belong to
-/// the
-/// [standard error code](https://docs.microsoft.com/en-us/windows/win32/debug/system-error-codes)
-/// of the same value. Do not rely on these descriptions.
-pub fn CommDlgExtendedError() -> co::ERROR {
-	co::ERROR(unsafe { comdlg32::CommDlgExtendedError() })
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::{CommandLineToArgv, GetCommandLine};
+///
+/// let args = CommandLineToArgv(&GetCommandLine()).unwrap();
+/// for arg in args.iter() {
+///     println!("{}", arg);
+/// }
+/// ```
+pub fn CommandLineToArgv(lpCmdLine: &str) -> WinResult<Vec<String>> {
+	let mut pNumArgs: i32 = 0;
+	let lpArr = unsafe {
+		shell32::CommandLineToArgvW(
+			WString::from_str(lpCmdLine).as_ptr(),
+			&mut pNumArgs,
+		)
+	};
+	if lpArr.is_null() {
+		return Err(GetLastError());
+	}
+
+	let mut strs = Vec::with_capacity(pNumArgs as _);
+	for lp in unsafe { std::slice::from_raw_parts(lpArr, pNumArgs as _) }.iter() {
+		strs.push(WString::from_wchars_nullt(*lp).to_string());
+	}
+
+	(HLOCAL { ptr: lpArr as _ })
+		.LocalFree()
+		.map(|_| strs)
+}
+
+/// [`CommDlgExtendedError`](https://docs.microsoft.com/en-us/windows/win32/api/commdlg/nf-commdlg-commdlgextendederror)
+/// function.
+pub fn CommDlgExtendedError() -> co::CDERR {
+	co::CDERR(unsafe { comdlg32::CommDlgExtendedError() })
 }
 
 /// [`CopyFile`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-copyfilew)
@@ -188,8 +252,44 @@ pub fn EncryptionDisable(DirPath: &str, Disable: bool) -> WinResult<()> {
 	)
 }
 
+/// [`EndMenu`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-endmenu)
+/// function.
+pub fn EndMenu() -> WinResult<()> {
+	bool_to_winresult(unsafe { user32::EndMenu() })
+}
+
+/// [`EnumDisplaySettingsEx`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-enumdisplaysettingsexw)
+/// function
+pub fn EnumDisplaySettingsEx(
+	lpszDeviceName: Option<&str>,
+	iModeNum: co::ENUM_SETTINGS,
+	lpDevMode: &mut DEVMODE,
+	dwFlags: co::EDS) -> WinResult<()>
+{
+	bool_to_winresult(
+		unsafe {
+			user32::EnumDisplaySettingsExW(
+				lpszDeviceName.map_or(std::ptr::null(), |lp| WString::from_str(lp).as_ptr()),
+				iModeNum.0,
+				lpDevMode as *mut _ as _,
+				dwFlags.0
+			)
+		},
+	)
+}
+
 /// [`ExpandEnvironmentStrings`](https://docs.microsoft.com/en-us/windows/win32/api/processenv/nf-processenv-expandenvironmentstringsw)
 /// function.
+///
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::ExpandEnvironmentStrings;
+///
+/// println("{}", ExpandEnvironmentStrings(
+///     "Os %OS%, home %HOMEPATH%, temp %TEMP%",
+/// ).unwrap());
+/// ```
 pub fn ExpandEnvironmentStrings(lpSrc: &str) -> WinResult<String> {
 	let wsrc = WString::from_str(lpSrc);
 	let len = unsafe {
@@ -244,16 +344,46 @@ pub fn GetBinaryType(lpApplicationName: &str) -> WinResult<co::SCS> {
 				WString::from_str(lpApplicationName).as_ptr(),
 				&mut lpBinaryType.0,
 			)
-		}
+		},
 	).map(|_| lpBinaryType)
 }
 
 /// [`GetClipCursor`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getclipcursor)
-/// method.
+/// function.
 pub fn GetClipCursor(lpRect: &mut RECT) -> WinResult<()> {
 	bool_to_winresult(unsafe { user32::GetClipCursor(lpRect as *mut _ as _) })
 }
 
+/// [`GetCommandLine`](https://docs.microsoft.com/en-us/windows/win32/api/processenv/nf-processenv-getcommandlinew)
+/// function.
+///
+/// For an example, see [`CommandLineToArgv`](crate::CommandLineToArgv).
+pub fn GetCommandLine() -> String {
+	WString::from_wchars_nullt(unsafe { kernel32::GetCommandLineW() }).to_string()
+}
+
+/// [`GetComputerName`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-getcomputernamew)
+/// function.
+pub fn GetComputerName() -> WinResult<String> {
+	let mut buf = WString::new_alloc_buffer(MAX_COMPUTERNAME_LENGTH + 1);
+	let mut sz = buf.buffer_size() as u32;
+	bool_to_winresult(
+		unsafe { kernel32::GetComputerNameW(buf.as_mut_ptr(), &mut sz) },
+	).map(|_| buf.to_string())
+}
+
+/// [`GetCurrentProcessId`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-getcurrentprocessid)
+/// function.
+pub fn GetCurrentProcessId() -> u32 {
+	unsafe { kernel32::GetCurrentProcessId() }
+}
+
+/// [`GetCurrentThreadId`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-getcurrentthreadid)
+/// function.
+pub fn GetCurrentThreadId() -> u32 {
+	unsafe { kernel32::GetCurrentThreadId() }
+}
+
 /// [`GetCursorPos`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getcursorpos)
 /// function.
 pub fn GetCursorPos() -> WinResult<POINT> {
@@ -311,7 +441,7 @@ pub fn GetEnvironmentStrings() -> WinResult<HashMap<String, String>> {
 }
 
 /// [`GetFileAttributes`](https://docs.microsoft.com/en-us/windows/win32/api/fileapi/nf-fileapi-getfileattributesw)
-/// method.
+/// function.
 ///
 /// # Examples
 ///
@@ -346,6 +476,76 @@ pub fn GetFileAttributes(lpFileName: &str) -> WinResult<co::FILE_ATTRIBUTE> {
 	}
 }
 
+/// [`GetFileVersionInfo`](https://docs.microsoft.com/en-us/windows/win32/api/winver/nf-winver-getfileversioninfow)
+/// function.
+///
+/// The passed buffer will be automatically allocated with
+/// [`GetFileVersionInfoSize`](crate::GetFileVersionInfoSize).
+pub fn GetFileVersionInfo(
+	lptstrFilename: &str, lpData: &mut Vec<u8>) -> WinResult<()>
+{
+	lpData.resize(GetFileVersionInfoSize(lptstrFilename).unwrap() as _, 0);
+	bool_to_winresult(
+		unsafe {
+			version::GetFileVersionInfoW(
+				WString::from_str(lptstrFilename).as_ptr(),
+				0,
+				lpData.len() as _,
+				lpData.as_mut_ptr() as _,
+			)
+		},
+	)
+}
+
+/// [`GetFileVersionInfoSize`](https://docs.microsoft.com/en-us/windows/win32/api/winver/nf-winver-getfileversioninfosizew)
+/// function.
+pub fn GetFileVersionInfoSize(lptstrFilename: &str) -> WinResult<u32> {
+	let mut lpdwHandle = 0;
+	match unsafe {
+		version::GetFileVersionInfoSizeW(
+			WString::from_str(lptstrFilename).as_ptr(),
+			&mut lpdwHandle,
+		)
+	} {
+		0 => Err(GetLastError()),
+		sz => Ok(sz)
+	}
+}
+
+/// [`GetFirmwareType`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-getfirmwaretype)
+/// function.
+pub fn GetFirmwareType() -> WinResult<co::FIRMWARE_TYPE> {
+	let mut ft: u32 = 0;
+	bool_to_winresult(unsafe { kernel32::GetFirmwareType(&mut ft) })
+		.map(|_| co::FIRMWARE_TYPE(ft))
+}
+
+/// [`GetGUIThreadInfo`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getguithreadinfo)
+/// function.
+///
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::{GetGUIThreadInfo, GUITHREADINFO, HWND};
+///
+/// let hwnd: HWND; // initialized somewhere
+///
+/// let mut gti = GUITHREADINFO::default();
+/// GetGUIThreadInfo(
+///     hwnd.GetWindowThreadProcessId(),
+///     &mut gti,
+/// ).unwrap();
+///
+/// println!("Caret rect: {}", gti.rcCaret);
+/// ```
+pub fn GetGUIThreadInfo(
+	idThread: u32, pgui: &mut GUITHREADINFO) -> WinResult<()>
+{
+	bool_to_winresult(
+		unsafe { user32::GetGUIThreadInfo(idThread, pgui as *mut _ as _) }
+	)
+}
+
 /// [`GetLargePageMinimum`](https://docs.microsoft.com/en-us/windows/win32/api/memoryapi/nf-memoryapi-getlargepageminimum)
 /// function.
 pub fn GetLargePageMinimum() -> u64 {
@@ -382,6 +582,13 @@ pub fn GetLogicalDriveStrings() -> WinResult<Vec<String>> {
 	}
 }
 
+/// [`GetMenuCheckMarkDimensions`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmenucheckmarkdimensions)
+/// function.
+pub fn GetMenuCheckMarkDimensions() -> SIZE {
+	let dims = unsafe { user32::GetMenuCheckMarkDimensions() };
+	SIZE::new(LOWORD(dims as _) as _, HIWORD(dims as _) as _)
+}
+
 /// [`GetMessage`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmessagew)
 /// function.
 pub fn GetMessage(lpMsg: &mut MSG, hWnd: Option<HWND>,
@@ -400,18 +607,55 @@ pub fn GetMessage(lpMsg: &mut MSG, hWnd: Option<HWND>,
 	}
 }
 
+/// [`GetMessagePos`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmessagepos)
+/// function.
+pub fn GetMessagePos() -> POINT {
+	let xy = unsafe { user32::GetMessagePos() };
+	POINT::new(LOWORD(xy) as _, HIWORD(xy) as _)
+}
+
+/// [`GetNativeSystemInfo`](https://docs.microsoft.com/en-us/windows/win32/api/sysinfoapi/nf-sysinfoapi-getnativesysteminfo)
+/// function.
+pub fn GetNativeSystemInfo(lpSystemInfo: &mut SYSTEM_INFO) {
+	unsafe { kernel32::GetNativeSystemInfo(lpSystemInfo as *mut _ as _) }
+}
+
 /// [`GetQueueStatus`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getqueuestatus)
 /// function.
 pub fn GetQueueStatus(flags: co::QS) -> u32 {
 	unsafe { user32::GetQueueStatus(flags.0) }
 }
 
+/// [`GetStartupInfo`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-getstartupinfow)
+/// function.
+pub fn GetStartupInfo(lpStartupInfo: &mut STARTUPINFO) {
+	unsafe { kernel32::GetStartupInfoW(lpStartupInfo as *mut _ as _) }
+}
+
 /// [`GetSysColor`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getsyscolor)
 /// function.
 pub fn GetSysColor(nIndex: co::COLOR) -> COLORREF {
 	COLORREF(unsafe { user32::GetSysColor(nIndex.0) })
 }
 
+/// [`GetSystemDirectory`](https://docs.microsoft.com/en-us/windows/win32/api/sysinfoapi/nf-sysinfoapi-getsystemdirectoryw)
+/// function.
+pub fn GetSystemDirectory() -> WinResult<String> {
+	let mut buf = WString::new_alloc_buffer(MAX_PATH + 1);
+	match unsafe {
+		kernel32::GetSystemDirectoryW(buf.as_mut_ptr(), buf.buffer_size() as _)
+	} {
+		0 => Err(GetLastError()),
+		_ => Ok(buf.to_string()),
+	}
+}
+
+/// [`GetSystemInfo`](https://docs.microsoft.com/en-us/windows/win32/api/sysinfoapi/nf-sysinfoapi-getsysteminfo)
+/// function.
+pub fn GetSystemInfo(lpSystemInfo: &mut SYSTEM_INFO) {
+	unsafe { kernel32::GetSystemInfo(lpSystemInfo as *mut _ as _) }
+}
+
 /// [`GetSystemMetrics`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getsystemmetrics)
 /// function.
 pub fn GetSystemMetrics(nIndex: co::SM) -> i32 {
@@ -442,6 +686,24 @@ pub fn GetSystemTimePreciseAsFileTime(lpSystemTimeAsFileTime: &mut FILETIME) {
 	}
 }
 
+/// [`GetSystemTimes`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-getsystemtimes)
+/// function.
+pub fn GetSystemTimes(
+	lpIdleTime: &mut FILETIME,
+	lpKernelTime: &mut FILETIME,
+	lpUserTime: &mut FILETIME) -> WinResult<()>
+{
+	bool_to_winresult(
+		unsafe {
+			kernel32::GetSystemTimes(
+				lpIdleTime as *mut _ as _,
+				lpKernelTime as *mut _ as _,
+				lpUserTime as *mut _ as _,
+			)
+		},
+	)
+}
+
 /// [`GetTempPath`](https://docs.microsoft.com/en-us/windows/win32/api/fileapi/nf-fileapi-gettemppathw)
 /// function.
 pub fn GetTempPath() -> WinResult<String> {
@@ -454,6 +716,17 @@ pub fn GetTempPath() -> WinResult<String> {
 	}
 }
 
+/// [`GetUserName`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-getusernamew)
+/// function.
+pub fn GetUserName() -> WinResult<String> {
+	let mut buf = WString::new_alloc_buffer(UNLEN + 1);
+	let mut sz = buf.buffer_size() as u32;
+	match unsafe { advapi32::GetUserNameW(buf.as_mut_ptr(), &mut sz) } {
+		0 => Err(GetLastError()),
+		_ => Ok(buf.to_string()),
+	}
+}
+
 /// [`GetTickCount64`](https://docs.microsoft.com/en-us/windows/win32/api/sysinfoapi/nf-sysinfoapi-gettickcount64)
 /// function.
 pub fn GetTickCount64() -> u64 {
@@ -512,6 +785,16 @@ pub fn IsGUIThread(bConvert: bool) -> WinResult<bool> {
 	}
 }
 
+/// [`IsNativeVhdBoot`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-isnativevhdboot)
+/// function.
+pub fn IsNativeVhdBoot() -> WinResult<bool> {
+	let mut nativeVhdBoot: BOOL = 0;
+	match unsafe { kernel32::IsNativeVhdBoot(&mut nativeVhdBoot) } {
+		0 => Err(GetLastError()),
+		_ => Ok(nativeVhdBoot != 0),
+	}
+}
+
 /// [`IsWindows10OrGreater`](https://docs.microsoft.com/en-us/windows/win32/api/versionhelpers/nf-versionhelpers-iswindows10orgreater)
 /// function.
 pub fn IsWindows10OrGreater() -> WinResult<bool> {
@@ -599,6 +882,12 @@ pub fn IsWindowsVistaOrGreater() -> WinResult<bool> {
 	)
 }
 
+/// [`IsWow64Message`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-iswow64message)
+/// function.
+pub fn IsWow64Message() -> bool {
+	return unsafe { user32::IsWow64Message() != 0}
+}
+
 /// [`LOBYTE`](https://docs.microsoft.com/en-us/previous-versions/windows/desktop/legacy/ms632658(v=vs.85))
 /// function. Originally a macro.
 pub const fn LOBYTE(v: u16) -> u8 {
@@ -668,6 +957,8 @@ pub fn MulDiv(nNumber: i32, nNumerator: i32, nDenominator: i32) -> i32 {
 
 /// [`MultiByteToWideChar`](https://docs.microsoft.com/en-us/windows/win32/api/stringapiset/nf-stringapiset-multibytetowidechar)
 /// function.
+///
+/// The resulting `Vec<u16>` includes a terminating null.
 pub fn MultiByteToWideChar(
 	CodePage: co::CP, dwFlags: co::MBC,
 	lpMultiByteStr: &[u8]) -> WinResult<Vec<u16>> {
@@ -684,7 +975,8 @@ pub fn MultiByteToWideChar(
 	} {
 		0 => Err(GetLastError()),
 		numBytes => {
-			let mut destBuf: Vec<u16> = vec![0, numBytes as _];
+			let numBytes = numBytes as usize + 1; // add room for terminating null
+			let mut destBuf: Vec<u16> = vec![0x0000; numBytes as _];
 
 			match unsafe {
 				kernel32::MultiByteToWideChar(
@@ -697,7 +989,10 @@ pub fn MultiByteToWideChar(
 				)
 			} {
 				0 => Err(GetLastError()),
-				_ => Ok(destBuf),
+				_ => {
+					unsafe { *destBuf.get_unchecked_mut(numBytes - 1) = 0x0000; } // terminating null
+					Ok(destBuf)
+				},
 			}
 		},
 	}
@@ -733,6 +1028,40 @@ pub fn PostQuitMessage(nExitCode: co::ERROR) {
 	unsafe { user32::PostQuitMessage(nExitCode.0 as _) }
 }
 
+/// [`QueryPerformanceCounter`](https://docs.microsoft.com/en-us/windows/win32/api/profileapi/nf-profileapi-queryperformancecounter)
+/// function.
+///
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::{QueryPerformanceCounter, QueryPerformanceFrequency};
+///
+/// let freq = QueryPerformanceFrequency().unwrap();
+/// let start = QueryPerformanceCounter().unwrap();
+///
+/// // perform some operation...
+///
+/// let duration_ms =
+///     ((QueryPerformanceCounter().unwrap() - t0) as f64 / freq as f64) * 1000.0;
+///
+/// println!("Operation lasted {:.2} ms", duration_ms);
+/// ```
+pub fn QueryPerformanceCounter() -> WinResult<i64> {
+	let mut lpPerformanceCount: i64 = 0;
+	bool_to_winresult(
+		unsafe { kernel32::QueryPerformanceCounter(&mut lpPerformanceCount) },
+	).map(|_| lpPerformanceCount)
+}
+
+/// [`QueryPerformanceFrequency`](https://docs.microsoft.com/en-us/windows/win32/api/profileapi/nf-profileapi-queryperformancecounter)
+/// function.
+pub fn QueryPerformanceFrequency() -> WinResult<i64> {
+	let mut lpFrequency: i64 = 0;
+	bool_to_winresult(
+		unsafe { kernel32::QueryPerformanceFrequency(&mut lpFrequency) },
+	).map(|_| lpFrequency)
+}
+
 /// [`RegisterClassEx`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-registerclassexw)
 /// function.
 pub fn RegisterClassEx(lpwcx: &WNDCLASSEX) -> WinResult<ATOM> {
@@ -788,6 +1117,60 @@ pub fn SetProcessDPIAware() -> WinResult<()> {
 	bool_to_winresult(unsafe { user32::SetProcessDPIAware() })
 }
 
+/// [`SHAddToRecentDocs`](https://docs.microsoft.com/en-us/windows/win32/api/shlobj_core/nf-shlobj_core-shaddtorecentdocs)
+/// function.
+///
+/// **Note:** The `pv` type varies according to `uFlags`. If you set it wrong,
+/// you're likely to cause a buffer overrun.
+pub unsafe fn SHAddToRecentDocs<T>(uFlags: co::SHARD, pv: &T) {
+	shell32::SHAddToRecentDocs(uFlags.0, pv as *const _ as _);
+}
+
+/// [`Shell_NotifyIcon`](https://docs.microsoft.com/en-us/windows/win32/api/shellapi/nf-shellapi-shell_notifyiconw)
+/// function.
+pub fn Shell_NotifyIcon(
+	dwMessage: co::NIM, lpData: &mut NOTIFYICONDATA) -> WinResult<()>
+{
+	bool_to_winresult(
+		unsafe { shell32::Shell_NotifyIconW(dwMessage.0, lpData as *mut _ as _) },
+	)
+}
+
+/// [`SHGetFileInfo`](https://docs.microsoft.com/en-us/windows/win32/api/shellapi/nf-shellapi-shgetfileinfow)
+/// function.
+///
+/// **Note:** If you are returning an icon in the `hIcon` member of
+/// [`SHFILEINFO`](crate::SHFILEINFO), it must be paired with an
+/// [`HICON::DestroyIcon`](crate::HICON::DestroyIcon) call.
+pub fn SHGetFileInfo(
+	pszPath: &str, dwFileAttributes: co::FILE_ATTRIBUTE,
+	psfi: &mut SHFILEINFO, uFlags: co::SHGFI) -> WinResult<u32>
+{
+	match unsafe {
+		shell32::SHGetFileInfoW(
+			WString::from_str(pszPath).as_ptr(),
+			dwFileAttributes.0,
+			psfi as *mut _ as _,
+			std::mem::size_of::<SHFILEINFO>() as _,
+			uFlags.0,
+		)
+	} {
+		0 => Err(GetLastError()),
+		n => Ok(n as _),
+	}
+}
+
+/// [`SHFileOperation`](https://docs.microsoft.com/en-us/windows/win32/api/shellapi/nf-shellapi-shfileoperationw)
+/// function.
+pub fn SHFileOperation(lpFileOp: &mut SHFILEOPSTRUCT) -> WinResult<()> {
+	match unsafe {
+		shell32::SHFileOperationW(lpFileOp as *mut _ as _)
+	} {
+		0 => Err(GetLastError()),
+		_ => Ok(()),
+	}
+}
+
 /// [`ShowCursor`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-showcursor)
 /// function.
 pub fn ShowCursor(bShow: bool) -> i32 {
@@ -809,8 +1192,8 @@ pub fn SoundSentry() -> bool {
 /// [`SystemParametersInfo`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-systemparametersinfow)
 /// function.
 ///
-/// The `pvParam` type varies according to the `uiAction`. If you set it wrong,
-/// you're likely to cause a buffer overrun.
+/// **Note:** The `pvParam` type varies according to `uiAction`. If you set it
+/// wrong, you're likely to cause a buffer overrun.
 pub unsafe fn SystemParametersInfo<T>(
 	uiAction: co::SPI,
 	uiParam: u32,
@@ -860,6 +1243,77 @@ pub fn SystemTimeToTzSpecificLocalTime(
 	)
 }
 
+/// [`TaskDialogIndirect`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-taskdialogindirect)
+/// function.
+///
+/// Returns:
+/// * the selected `co::DLGID` button;
+/// * if `pRadioButtons` of [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) struct
+/// was set, the `u16` control ID of one of the specified radio buttons;
+/// otherwise zero.
+///
+/// If you don't need all customizations, consider the
+/// [`TaskDialog`](crate::HWND::TaskDialog) method.
+///
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::{co, gui, IconIdTdicon,
+///     TASKDIALOG_BUTTON TASKDIALOGCONFIG, TaskDialogIndirect,
+///     WString};
+///
+/// let wnd: gui::WindowMain; // initialized somewhere
+///
+/// let mut tdc = TASKDIALOGCONFIG::default();
+/// tdc.hwndParent = wnd.hwnd();
+/// tdc.dwCommonButtons = co::TDCBF::YES | co::TDCBF::NO;
+/// tdc.set_hMainIcon(IconIdTdicon::Tdicon(co::TD_ICON::INFORMATION));
+///
+/// let mut title = WString::from_str("Title");
+/// tdc.set_pszWindowTitle(Some(&mut title));
+///
+/// let mut header = WString::from_str("Header");
+/// tdc.set_pszMainInstruction(Some(&mut header));
+///
+/// let mut body = WString::from_str("Body");
+/// tdc.set_pszContent(Some(&mut body));
+///
+/// // A custom button to appear before Yes and No.
+/// let mut btn1 = TASKDIALOG_BUTTON::default();
+/// let mut btn1_text = WString::from_str("Hello");
+/// btn1.set_pszButtonText(Some(&mut btn1_text));
+/// btn1.set_nButtonID(333); // this ID is returned if user clicks this button
+/// let btns_slice = &mut [btn1];
+/// tdc.set_pButtons(Some(btns_slice));
+///
+/// TaskDialogIndirect(&tdc, None).unwrap();
+/// ```
+pub fn TaskDialogIndirect(
+	pTaskConfig: &TASKDIALOGCONFIG,
+	pfVerificationFlagChecked: Option<&mut bool>) -> WinResult<(co::DLGID, u16)>
+{
+	let mut pnButton: i32 = 0;
+	let mut pnRadioButton: i32 = 0;
+	let mut pfBool: BOOL = 0;
+
+	hr_to_winresult(
+		unsafe {
+			comctl32::TaskDialogIndirect(
+				pTaskConfig as *const _ as _,
+				&mut pnButton,
+				&mut pnRadioButton,
+				pfVerificationFlagChecked.as_ref()
+					.map_or(std::ptr::null_mut(), |_| &mut pfBool),
+			)
+		},
+	)?;
+
+	if let Some(pf) = pfVerificationFlagChecked {
+		*pf = pfBool != 0;
+	}
+	Ok((co::DLGID(pnButton as _), pnRadioButton as _))
+}
+
 /// [`TrackMouseEvent`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-trackmouseevent)
 /// function.
 pub fn TrackMouseEvent(lpEventTrack: &mut TRACKMOUSEEVENT) -> WinResult<()> {
@@ -889,6 +1343,46 @@ pub fn UnregisterClass(
 	)
 }
 
+/// [`VarQueryValue`](https://docs.microsoft.com/en-us/windows/win32/api/winver/nf-winver-verqueryvaluew)
+/// function.
+///
+/// **Note:** The returned reference type varies according to `lpSubBlock`. If
+/// you set it wrong, you're likely to cause a buffer overrun.
+///
+/// # Examples
+///
+/// Reading version information from resource:
+///
+/// ```rust,ignore
+/// use winsafe::{HINSTANCE, VS_FIXEDFILEINFO};
+/// use winsafe::{GetFileVersionInfo, VarQueryValue};
+///
+/// let exe_name = HINSTANCE::NULL.GetModuleFileName().unwrap();
+/// let mut res_buf = Vec::default();
+/// GetFileVersionInfo(&exe_name, &mut res_buf).unwrap();
+///
+/// let vsffi = unsafe {
+///     VarQueryValue::<VS_FIXEDFILEINFO>(&res_buf, "\\").unwrap()
+/// };
+/// let ver = vsffi.dwFileVersion();
+/// println!("Version {}.{}.{}.{}",
+///     ver[0], ver[1], ver[2], ver[3]);
+/// ```
+pub unsafe fn VarQueryValue<'a, T>(
+	pBlock: &'a [u8], lpSubBlock: &str) -> WinResult<&'a T>
+{
+	let mut lplpBuffer = std::ptr::null();
+	let mut puLen = 0;
+	bool_to_winresult(
+		version::VerQueryValueW(
+			pBlock.as_ptr() as _,
+			WString::from_str(lpSubBlock).as_ptr(),
+			&mut lplpBuffer as *mut _ as _,
+			&mut puLen,
+		),
+	).map(|_| &*(lplpBuffer as *const T))
+}
+
 /// [`VerifyVersionInfo`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-verifyversioninfow)
 /// function.
 pub fn VerifyVersionInfo(
@@ -929,6 +1423,8 @@ pub fn WaitMessage() -> WinResult<()> {
 
 /// [`WideCharToMultiByte`](https://docs.microsoft.com/en-us/windows/win32/api/stringapiset/nf-stringapiset-widechartomultibyte)
 /// function.
+///
+/// The resulting `Vec<u16>` includes a terminating null.
 pub fn WideCharToMultiByte(
 	CodePage: co::CP, dwFlags: co::WC,
 	lpWideCharStr: &[u16], lpDefaultChar: Option<u8>,
@@ -950,7 +1446,8 @@ pub fn WideCharToMultiByte(
 	} {
 		0 => Err(GetLastError()),
 		numBytes => {
-			let mut destBuf: Vec<u8> = vec![0; numBytes as _];
+			let numBytes = numBytes as usize + 1; // add room for terminating null
+			let mut destBuf: Vec<u8> = vec![0x00; numBytes as _];
 			let mut boolBuf: BOOL = 0;
 
 			match unsafe {
@@ -960,7 +1457,7 @@ pub fn WideCharToMultiByte(
 					lpWideCharStr.as_ptr(),
 					lpWideCharStr.len() as _,
 					destBuf.as_mut_ptr() as _,
-					numBytes,
+					numBytes as _,
 					&mut lpDefaulCharBuf,
 					&mut boolBuf,
 				)
@@ -970,6 +1467,7 @@ pub fn WideCharToMultiByte(
 					if let Some(lp) = lpUsedDefaultChar {
 						*lp = boolBuf != 0;
 					}
+					unsafe { *destBuf.get_unchecked_mut(numBytes - 1) = 0x00; } // terminating null
 					Ok(destBuf)
 				},
 			}
