@@ -3,7 +3,7 @@ use std::rc::Rc;
 use crate::co;
 use crate::gui::events::func_store::FuncStore;
 use crate::gui::very_unsafe_cell::VeryUnsafeCell;
-use crate::handles::{HDC, HFONT, HICON, HMENU};
+use crate::handles::{HBRUSH, HFONT, HICON, HMENU};
 use crate::msg::{MsgSendRecv, wm, WndMsg};
 
 /// The result of processing a message.
@@ -28,19 +28,19 @@ pub struct WindowEvents(VeryUnsafeCell<Obj>);
 struct Obj { // actual fields of WindowEvents
 	msgs: FuncStore< // ordinary WM messages
 		co::WM,
-		Box<dyn FnMut(WndMsg) -> Option<isize>>, // return value may be meaningful
+		Box<dyn Fn(WndMsg) -> Option<isize>>, // return value may be meaningful
 	>,
 	tmrs: FuncStore< // WM_TIMER messages
 		u32,
-		Box<dyn FnMut()>, // return value is never meaningful
+		Box<dyn Fn()>, // return value is never meaningful
 	>,
 	cmds: FuncStore< // WM_COMMAND notifications
 		(co::CMD, u16), // notif code, control ID
-		Box<dyn FnMut()>, // return value is never meaningful
+		Box<dyn Fn()>, // return value is never meaningful
 	>,
 	nfys: FuncStore< // WM_NOTIFY notifications
 		(u16, co::NM), // idFrom, code
-		Box<dyn FnMut(wm::Notify) -> Option<isize>>, // return value may be meaningful
+		Box<dyn Fn(wm::Notify) -> Option<isize>>, // return value may be meaningful
 	>,
 }
 
@@ -72,8 +72,8 @@ impl WindowEvents {
 		match wm_any.msg_id {
 			co::WM::NOTIFY => {
 				let wm_nfy = wm::Notify::from_generic_wm(wm_any);
-				let key = (wm_nfy.nmhdr.idFrom as u16, wm_nfy.nmhdr.code);
-				match self.0.as_mut().nfys.find(key) {
+				let key = (wm_nfy.nmhdr.idFrom(), wm_nfy.nmhdr.code);
+				match self.0.nfys.find(key) {
 					Some(func) => { // we have a stored function to handle this WM_NOTIFY notification
 						match func(wm_nfy) { // execute user function
 							Some(res) => ProcessResult::HandledWithRet(res), // meaningful return value
@@ -86,7 +86,7 @@ impl WindowEvents {
 			co::WM::COMMAND => {
 				let wm_cmd = wm::Command::from_generic_wm(wm_any);
 				let key = wm_cmd.event.code_id();
-				match self.0.as_mut().cmds.find(key) {
+				match self.0.cmds.find(key) {
 					Some(func) => { // we have a stored function to handle this WM_COMMAND notification
 						func(); // execute user function
 						ProcessResult::HandledWithoutRet
@@ -96,7 +96,7 @@ impl WindowEvents {
 			},
 			co::WM::TIMER => {
 				let wm_tmr = wm::Timer::from_generic_wm(wm_any);
-				match self.0.as_mut().tmrs.find(wm_tmr.timer_id) {
+				match self.0.tmrs.find(wm_tmr.timer_id) {
 					Some(func) => { // we have a stored function to handle this WM_TIMER message
 						func(); // execute user function
 						ProcessResult::HandledWithoutRet
@@ -105,7 +105,7 @@ impl WindowEvents {
 				}
 			}
 			_ => { // any other message
-				match self.0.as_mut().msgs.find(wm_any.msg_id) {
+				match self.0.msgs.find(wm_any.msg_id) {
 					Some(func) => { // we have a stored function to handle this message
 						match func(wm_any) { // execute user function
 							Some(res) => ProcessResult::HandledWithRet(res), // meaningful return value
@@ -124,26 +124,26 @@ impl WindowEvents {
 		match wm_any.msg_id {
 			co::WM::NOTIFY => {
 				let wm_nfy = wm::Notify::from_generic_wm(wm_any);
-				let key = (wm_nfy.nmhdr.idFrom as u16, wm_nfy.nmhdr.code);
-				self.0.as_mut().nfys.find_all(key, |func| {
+				let key = (wm_nfy.nmhdr.idFrom(), wm_nfy.nmhdr.code);
+				self.0.nfys.find_all(key, |func| {
 					func(wm_nfy);
 				});
 			},
 			co::WM::COMMAND => {
 				let wm_cmd = wm::Command::from_generic_wm(wm_any);
 				let key = wm_cmd.event.code_id();
-				self.0.as_mut().cmds.find_all(key, |func| {
+				self.0.cmds.find_all(key, |func| {
 					func();
 				});
 			},
 			co::WM::TIMER => {
 				let wm_tmr = wm::Timer::from_generic_wm(wm_any);
-				self.0.as_mut().tmrs.find_all(wm_tmr.timer_id, |func| {
+				self.0.tmrs.find_all(wm_tmr.timer_id, |func| {
 					func();
 				});
 			},
 			_ => { // any other message
-				self.0.as_mut().msgs.find_all(wm_any.msg_id, |func| {
+				self.0.msgs.find_all(wm_any.msg_id, |func| {
 					func(wm_any);
 				});
 			},
@@ -152,14 +152,14 @@ impl WindowEvents {
 
 	/// Raw add message.
 	pub(crate) fn add_msg<F>(&self, ident: co::WM, func: F)
-		where F: FnMut(WndMsg) -> Option<isize> + 'static,
+		where F: Fn(WndMsg) -> Option<isize> + 'static,
 	{
 		self.0.as_mut().msgs.insert(ident, Box::new(func));
 	}
 
 	/// Raw add notification.
 	pub(crate) fn add_nfy<F>(&self, id_from: u16, code: co::NM, func: F)
-		where F: FnMut(wm::Notify) -> Option<isize> + 'static,
+		where F: Fn(wm::Notify) -> Option<isize> + 'static,
 	{
 		self.0.as_mut().nfys.insert((id_from, code), Box::new(func));
 	}
@@ -191,12 +191,9 @@ impl WindowEvents {
 	/// });
 	/// ```
 	pub fn wm<F>(&self, ident: co::WM, func: F)
-		where F: FnMut(WndMsg) -> isize + 'static,
+		where F: Fn(WndMsg) -> isize + 'static,
 	{
-		self.add_msg(ident, {
-			let mut func = func;
-			move |p| Some(func(p)) // return value is meaningful
-		});
+		self.add_msg(ident, move |p| Some(func(p))); // return value is meaningful
 	}
 
 	/// [`WM_TIMER`](crate::msg::wm::Timer) message, narrowed to a specific
@@ -204,7 +201,7 @@ impl WindowEvents {
 	///
 	/// Posted to the installing thread's message queue when a timer expires.
 	pub fn wm_timer<F>(&self, timer_id: u32, func: F)
-		where F: FnMut() + 'static,
+		where F: Fn() + 'static,
 	{
 		self.0.as_mut().tmrs.insert(timer_id, Box::new(func));
 	}
@@ -220,14 +217,14 @@ impl WindowEvents {
 	/// specific command notifications, which will give you the correct message
 	/// parameters. This generic method should be used when you have a custom,
 	/// non-standard window notification.
-	pub fn wm_command<F>(&self, code: co::CMD, ctrl_id: i32, func: F)
-		where F: FnMut() + 'static,
+	pub fn wm_command<F>(&self, code: co::CMD, ctrl_id: u16, func: F)
+		where F: Fn() + 'static,
 	{
-		self.0.as_mut().cmds.insert((code, ctrl_id as _), Box::new(func));
+		self.0.as_mut().cmds.insert((code, ctrl_id), Box::new(func));
 	}
 
 	/// [`WM_COMMAND`](crate::msg::wm::Command) message, handling both
-	/// `co::CMD::Accelerator` and `co::CMD::Menu`, for a specific command ID.
+	/// `CMD::Accelerator` and `CMD::Menu`, for a specific command ID.
 	///
 	/// Ideal to be used with menu commands whose IDs are shared with
 	/// accelerators.
@@ -248,8 +245,8 @@ impl WindowEvents {
 	///     }
 	/// });
 	/// ```
-	pub fn wm_command_accel_menu<F>(&self, ctrl_id: i32, func: F)
-		where F: FnMut() + 'static,
+	pub fn wm_command_accel_menu<F>(&self, ctrl_id: u16, func: F)
+		where F: Fn() + 'static,
 	{
 		let shared_func = Rc::new(VeryUnsafeCell::new(func));
 
@@ -276,12 +273,9 @@ impl WindowEvents {
 	/// struct. This generic method should be used when you have a custom,
 	/// non-standard window notification.
 	pub fn wm_notify<F>(&self, id_from: i32, code: co::NM, func: F)
-		where F: FnMut(wm::Notify) -> isize + 'static,
+		where F: Fn(wm::Notify) -> isize + 'static,
 	{
-		self.add_nfy(id_from as _, code, {
-			let mut func = func;
-			move |p| Some(func(p)) // return value is meaningful
-		});
+		self.add_nfy(id_from as _, code, move |p| Some(func(p))); // return value is meaningful
 	}
 
 	pub_fn_wm_ret0_param! { wm_activate, co::WM::ACTIVATE, wm::Activate,
@@ -317,12 +311,10 @@ impl WindowEvents {
 	/// for example, by clicking an application command button using the mouse
 	/// or typing an application command key on the keyboard.
 	pub fn wm_app_command<F>(&self, func: F)
-		where F: FnMut(wm::AppCommand) + 'static,
+		where F: Fn(wm::AppCommand) + 'static,
 	{
-		self.add_msg(co::WM::APPCOMMAND, {
-			let mut func = func;
-			move |p| { func(wm::AppCommand::from_generic_wm(p)); Some(true as _) }
-		});
+		self.add_msg(co::WM::APPCOMMAND,
+			move |p| { func(wm::AppCommand::from_generic_wm(p)); Some(true as _) });
 	}
 
 	pub_fn_wm_ret0! { wm_cancel_mode, co::WM::CANCELMODE,
@@ -333,8 +325,14 @@ impl WindowEvents {
 		/// or message box is displayed. Certain functions also send this
 		/// message explicitly to the specified window regardless of whether it
 		/// is the active window. For example, the
-		/// [`EnableWindow`](crate::HWND::EnableWindow) function sends this
-		/// message when disabling the specified window.
+		/// [`HWND::EnableWindow`](crate::HWND::EnableWindow) function sends
+		/// this message when disabling the specified window.
+	}
+
+	pub_fn_wm_ret0_param! { wm_capture_changed, co::WM::CAPTURECHANGED, wm::CaptureChanged,
+		/// [`WM_CAPTURECHANGED`](crate::msg::wm::CaptureChanged) message.
+		///
+		/// Sent to the window that is losing the mouse capture.
 	}
 
 	pub_fn_wm_ret0_param! { wm_char, co::WM::CHAR, wm::Char,
@@ -383,7 +381,7 @@ impl WindowEvents {
 	/// instead.
 	///
 	/// Sent when an application requests that a window be created by calling
-	/// the [`CreateWindowEx`](crate::HWND::CreateWindowEx) function. The
+	/// the [`HWND::CreateWindowEx`](crate::HWND::CreateWindowEx) function. The
 	/// message is sent before the function returns. The window procedure of the
 	/// new window receives this message after the window is created, but before
 	/// the window becomes visible.
@@ -408,12 +406,10 @@ impl WindowEvents {
 	/// });
 	/// ```
 	pub fn wm_create<F>(&self, func: F)
-		where F: FnMut(wm::Create) -> i32 + 'static,
+		where F: Fn(wm::Create) -> i32 + 'static,
 	{
-		self.add_msg(co::WM::CREATE, {
-			let mut func = func;
-			move |p| Some(func(wm::Create::from_generic_wm(p)) as _)
-		});
+		self.add_msg(co::WM::CREATE,
+			move |p| Some(func(wm::Create::from_generic_wm(p)) as _));
 	}
 
 	/// [`WM_CTLCOLORBTN`](crate::msg::wm::CtlColorBtn) message.
@@ -423,12 +419,10 @@ impl WindowEvents {
 	/// However, only owner-drawn buttons respond to the parent window
 	/// processing this message.
 	pub fn wm_ctl_color_btn<F>(&self, func: F)
-		where F: FnMut(wm::CtlColorBtn) -> HDC + 'static,
+		where F: Fn(wm::CtlColorBtn) -> HBRUSH + 'static,
 	{
-		self.add_msg(co::WM::CTLCOLORBTN, {
-			let mut func = func;
-			move |p| Some(func(wm::CtlColorBtn::from_generic_wm(p)).ptr as _)
-		});
+		self.add_msg(co::WM::CTLCOLORBTN,
+			move |p| Some(func(wm::CtlColorBtn::from_generic_wm(p)).ptr as _));
 	}
 
 	/// [`WM_CTLCOLORDLG`](crate::msg::wm::CtlColorDlg) message.
@@ -437,12 +431,10 @@ impl WindowEvents {
 	/// responding to this message, the dialog box can set its text and
 	/// background colors using the specified display device context handle.
 	pub fn wm_ctl_color_dlg<F>(&self, func: F)
-		where F: FnMut(wm::CtlColorDlg) -> HDC + 'static,
+		where F: Fn(wm::CtlColorDlg) -> HBRUSH + 'static,
 	{
-		self.add_msg(co::WM::CTLCOLORDLG, {
-			let mut func = func;
-			move |p| Some(func(wm::CtlColorDlg::from_generic_wm(p)).ptr as _)
-		});
+		self.add_msg(co::WM::CTLCOLORDLG,
+			move |p| Some(func(wm::CtlColorDlg::from_generic_wm(p)).ptr as _));
 	}
 
 	/// [`WM_CTLCOLOREDIT`](crate::msg::wm::CtlColorEdit) message.
@@ -452,12 +444,10 @@ impl WindowEvents {
 	/// to this message, the parent window can use the specified device context
 	/// handle to set the text and background colors of the edit control.
 	pub fn wm_ctl_color_edit<F>(&self, func: F)
-		where F: FnMut(wm::CtlColorEdit) -> HDC + 'static,
+		where F: Fn(wm::CtlColorEdit) -> HBRUSH + 'static,
 	{
-		self.add_msg(co::WM::CTLCOLOREDIT, {
-			let mut func = func;
-			move |p| Some(func(wm::CtlColorEdit::from_generic_wm(p)).ptr as _)
-		});
+		self.add_msg(co::WM::CTLCOLOREDIT,
+			move |p| Some(func(wm::CtlColorEdit::from_generic_wm(p)).ptr as _));
 	}
 
 	/// [`WM_CTLCOLORLISTBOX`](crate::msg::wm::CtlColorListBox) message.
@@ -467,12 +457,10 @@ impl WindowEvents {
 	/// and background colors of the list box by using the specified display
 	/// device context handle.
 	pub fn wm_ctl_color_list_box<F>(&self, func: F)
-		where F: FnMut(wm::CtlColorListBox) -> HDC + 'static,
+		where F: Fn(wm::CtlColorListBox) -> HBRUSH + 'static,
 	{
-		self.add_msg(co::WM::CTLCOLORLISTBOX, {
-			let mut func = func;
-			move |p| Some(func(wm::CtlColorListBox::from_generic_wm(p)).ptr as _)
-		});
+		self.add_msg(co::WM::CTLCOLORLISTBOX,
+			move |p| Some(func(wm::CtlColorListBox::from_generic_wm(p)).ptr as _));
 	}
 
 	/// [`WM_CTLCOLORSCROLLBAR`](crate::msg::wm::CtlColorScrollBar) message.
@@ -482,12 +470,10 @@ impl WindowEvents {
 	/// use the display context handle to set the background color of the scroll
 	/// bar control.
 	pub fn wm_ctl_color_scroll_bar<F>(&self, func: F)
-		where F: FnMut(wm::CtlColorScrollBar) -> HDC + 'static,
+		where F: Fn(wm::CtlColorScrollBar) -> HBRUSH + 'static,
 	{
-		self.add_msg(co::WM::CTLCOLORSCROLLBAR, {
-			let mut func = func;
-			move |p| Some(func(wm::CtlColorScrollBar::from_generic_wm(p)).ptr as _)
-		});
+		self.add_msg(co::WM::CTLCOLORSCROLLBAR,
+			move |p| Some(func(wm::CtlColorScrollBar::from_generic_wm(p)).ptr as _));
 	}
 
 	/// [`WM_CTLCOLORSTATIC`](crate::msg::wm::CtlColorStatic) message.
@@ -498,12 +484,10 @@ impl WindowEvents {
 	/// specified device context handle to set the text foreground and
 	/// background colors of the static control.
 	pub fn wm_ctl_color_static<F>(&self, func: F)
-		where F: FnMut(wm::CtlColorStatic) -> HDC + 'static,
+		where F: Fn(wm::CtlColorStatic) -> HBRUSH + 'static,
 	{
-		self.add_msg(co::WM::CTLCOLORSTATIC, {
-			let mut func = func;
-			move |p| Some(func(wm::CtlColorStatic::from_generic_wm(p)).ptr as _)
-		});
+		self.add_msg(co::WM::CTLCOLORSTATIC,
+			move |p| Some(func(wm::CtlColorStatic::from_generic_wm(p)).ptr as _));
 	}
 
 	pub_fn_wm_ret0_param! { wm_dead_char, co::WM::DEADCHAR, wm::DeadChar,
@@ -550,6 +534,20 @@ impl WindowEvents {
 		///
 		/// Sent when the user drops a file on the window of an application that
 		/// has registered itself as a recipient of dropped files.
+		///
+		/// # Examples
+		///
+		/// ```rust,ignore
+		/// use winsafe::{gui, msg};
+		///
+		/// let wnd: gui::WindowMain; // initialized somewhere
+		///
+		/// wnd.on().wm_drop_files(|p: msg::wm::DropFiles| {
+		///     for dropped_file in p.hdrop.DragQueryFiles().unwrap().iter() {
+		///         println!("Dropped: {}", dropped_file);
+		///     }
+		/// });
+		/// ```
 	}
 
 	pub_fn_wm_ret0_param! { wm_enable, co::WM::ENABLE, wm::Enable,
@@ -557,9 +555,9 @@ impl WindowEvents {
 		///
 		/// Sent when an application changes the enabled state of a window. It
 		/// is sent to the window whose enabled state is changing. This message
-		/// is sent before the [`EnableWindow`](crate::HWND::EnableWindow)
+		/// is sent before the [`HWND::EnableWindow`](crate::HWND::EnableWindow)
 		/// function returns, but after the enabled state
-		/// ([`WS_DISABLED`](crate::co::WS::DISABLED) style bit) of the window
+		/// ([`WS::DISABLED`](crate::co::WS::DISABLED) style bit) of the window
 		/// has changed.
 	}
 
@@ -611,12 +609,10 @@ impl WindowEvents {
 	/// window is resized). The message is sent to prepare an invalidated
 	/// portion of a window for painting.
 	pub fn wm_erase_bkgnd<F>(&self, func: F)
-		where F: FnMut(wm::EraseBkgnd) -> i32 + 'static,
+		where F: Fn(wm::EraseBkgnd) -> i32 + 'static,
 	{
-		self.add_msg(co::WM::ERASEBKGND, {
-			let mut func = func;
-			move |p| Some(func(wm::EraseBkgnd::from_generic_wm(p)) as _)
-		});
+		self.add_msg(co::WM::ERASEBKGND,
+			move |p| Some(func(wm::EraseBkgnd::from_generic_wm(p)) as _));
 	}
 
 	pub_fn_wm_ret0_param! { wm_exit_menu_loop, co::WM::EXITMENULOOP, wm::ExitMenuLoop,
@@ -640,28 +636,38 @@ impl WindowEvents {
 		/// when `DefWindowProc` returns.
 	}
 
+	/// [`WM_GETDLGCODE`](crate::msg::wm::GetDlgCode) message.
+	///
+	/// By default, the system handles all keyboard input to the control; the
+	/// system interprets certain types of keyboard input as dialog box
+	/// navigation keys. To override this default behavior, the control can
+	/// respond to the `WM_GETDLGCODE` message to indicate the types of input it
+	/// wants to process itself.
+	pub fn wm_get_dlg_code<F>(&self, func: F)
+		where F: Fn(wm::GetDlgCode) -> co::DLGC + 'static,
+	{
+		self.add_msg(co::WM::GETDLGCODE,
+			move |p| Some(func(wm::GetDlgCode::from_generic_wm(p)).0 as _));
+	}
+
 	/// [`WM_GETFONT`](crate::msg::wm::GetFont) message.
 	///
 	/// Retrieves the font with which the control is currently drawing its text.
 	pub fn wm_get_font<F>(&self, func: F)
-		where F: FnMut() -> Option<HFONT> + 'static,
+		where F: Fn() -> Option<HFONT> + 'static,
 	{
-		self.add_msg(co::WM::GETFONT, {
-			let mut func = func;
-			move |_| Some(func().map(|h| h.ptr as _).unwrap_or_default())
-		});
+		self.add_msg(co::WM::GETFONT,
+			move |_| Some(func().map(|h| h.ptr as _).unwrap_or_default()));
 	}
 
 	/// [`MN_GETHMENU`](crate::msg::wm::GetHMenu) message.
 	///
 	/// Retrieves the menu handle for the current window.
 	pub fn wm_get_h_menu<F>(&self, func: F)
-		where F: FnMut() -> Option<HMENU> + 'static
+		where F: Fn() -> Option<HMENU> + 'static
 	{
-		self.add_msg(co::WM::MN_GETHMENU, {
-			let mut func = func;
-			move |_| Some(func().map(|h| h.ptr as _).unwrap_or_default())
-		});
+		self.add_msg(co::WM::MN_GETHMENU,
+			move |_| Some(func().map(|h| h.ptr as _).unwrap_or_default()));
 	}
 
 	pub_fn_wm_ret0_param! { wm_get_min_max_info, co::WM::GETMINMAXINFO, wm::GetMinMaxInfo,
@@ -836,12 +842,10 @@ impl WindowEvents {
 	/// Sent to the owner of a drag-and-drop menu when the user drags a menu
 	/// item.
 	pub fn wm_menu_drag<F>(&self, func: F)
-		where F: FnMut(wm::MenuDrag) -> co::MND + 'static,
+		where F: Fn(wm::MenuDrag) -> co::MND + 'static,
 	{
-		self.add_msg(co::WM::MENUDRAG, {
-			let mut func = func;
-			move |p| Some(func(wm::MenuDrag::from_generic_wm(p)).0 as _)
-		});
+		self.add_msg(co::WM::MENUDRAG,
+			move |p| Some(func(wm::MenuDrag::from_generic_wm(p)).0 as _));
 	}
 
 	pub_fn_wm_ret0_param! { wm_menu_r_button_up, co::WM::MENURBUTTONUP, wm::MenuRButtonUp,
@@ -859,6 +863,14 @@ impl WindowEvents {
 		/// [`TrackMouseEvent`](crate::TrackMouseEvent).
 	}
 
+	pub_fn_wm_ret0! { wm_mouse_leave, co::WM::MOUSELEAVE,
+		/// [`WM_MOUSELEAVE`](crate::msg::wm::MouseLeave) message.
+		///
+		/// Posted to a window when the cursor leaves the client area of the
+		/// window specified in a prior call to
+		/// [`TrackMouseEvent`](crate::TrackMouseEvent).
+	}
+
 	pub_fn_wm_ret0_param! { wm_mouse_move, co::WM::MOUSEMOVE, wm::MouseMove,
 		/// [`WM_MOUSEMOVE`](crate::msg::wm::MouseMove) message.
 		///
@@ -889,12 +901,10 @@ impl WindowEvents {
 	/// content of the window's client area when the size or position of the
 	/// window changes.
 	pub fn wm_nc_calc_size<F>(&self, func: F)
-		where F: FnMut(wm::NcCalcSize) -> co::WVR + 'static
+		where F: Fn(wm::NcCalcSize) -> co::WVR + 'static
 	{
-		self.add_msg(co::WM::NCCALCSIZE, {
-			let mut func = func;
-			move |p| Some(func(wm::NcCalcSize::from_generic_wm(p)).0 as _)
-		});
+		self.add_msg(co::WM::NCCALCSIZE,
+			move |p| Some(func(wm::NcCalcSize::from_generic_wm(p)).0 as _));
 	}
 
 	pub_fn_wm_retbool_param! { wm_nc_create, co::WM::NCCREATE, wm::NcCreate,
@@ -909,8 +919,8 @@ impl WindowEvents {
 		/// [`WM_NCDESTROY`](crate::msg::wm::NcDestroy) message.
 		///
 		/// Notifies a window that its nonclient area is being destroyed. The
-		/// [`DestroyWindow`](crate::HWND::DestroyWindow) function sends the
-		/// message to the window following the
+		/// [`HWND::DestroyWindow`](crate::HWND::DestroyWindow) function sends
+		/// the message to the window following the
 		/// [`WM_DESTROY`](crate::gui::events::WindowEvents::wm_destroy)
 		/// message. `WM_DESTROY` is used to free the allocated memory object
 		/// associated with the window.
@@ -933,17 +943,15 @@ impl WindowEvents {
 	/// corresponds to a particular screen coordinate. This can happen, for
 	/// example, when the cursor moves, when a mouse button is pressed or
 	/// released, or in response to a call to a function such as
-	/// [`WindowFromPoint`](crate::HWND::WindowFromPoint). If the mouse is not
-	/// captured, the message is sent to the window beneath the cursor.
+	/// [`HWND::WindowFromPoint`](crate::HWND::WindowFromPoint). If the mouse is
+	/// not captured, the message is sent to the window beneath the cursor.
 	/// Otherwise, the message is sent to the window that has captured the
 	/// mouse.
 	pub fn wm_nc_hit_test<F>(&self, func: F)
-		where F: FnMut(wm::NcHitTest) -> co::HT + 'static
+		where F: Fn(wm::NcHitTest) -> co::HT + 'static
 	{
-		self.add_msg(co::WM::NCHITTEST, {
-			let mut func = func;
-			move |p| Some(func(wm::NcHitTest::from_generic_wm(p)).0 as _)
-		});
+		self.add_msg(co::WM::NCHITTEST,
+			move |p| Some(func(wm::NcHitTest::from_generic_wm(p)).0 as _));
 	}
 
 	pub_fn_wm_ret0_param! { wm_nc_paint, co::WM::NCPAINT, wm::NcPaint,
@@ -978,11 +986,11 @@ impl WindowEvents {
 		///
 		/// Sent when the system or another application makes a request to paint
 		/// a portion of an application's window. The message is sent when the
-		/// [`UpdateWindow`](crate::HWND::UpdateWindow) or
-		/// [`RedrawWindow`](crate::HWND::RedrawWindow) function is called, or
-		/// by the [`DispatchMessage`](crate::DispatchMessage) function when the
-		/// application obtains a `WM_PAINT` message by using the
-		/// [`GetMessage`](crate::GetMessage) or
+		/// [`HWND::UpdateWindow`](crate::HWND::UpdateWindow) or
+		/// [`HWND::RedrawWindow`](crate::HWND::RedrawWindow) function is
+		/// called, or by the [`DispatchMessage`](crate::DispatchMessage)
+		/// function when the application obtains a `WM_PAINT` message by using
+		/// the [`GetMessage`](crate::GetMessage) or
 		/// [`PeekMessage`](crate::PeekMessage) function.
 	}
 
@@ -998,12 +1006,9 @@ impl WindowEvents {
 	/// Sent to an icon when the user requests that the window be restored to
 	/// its previous size and position.
 	pub fn wm_query_open<F>(&self, func: F)
-		where F: FnMut() -> bool + 'static,
+		where F: Fn() -> bool + 'static,
 	{
-		self.add_msg(co::WM::QUERYOPEN, {
-			let mut func = func;
-			move |_| Some(func() as _)
-		});
+		self.add_msg(co::WM::QUERYOPEN, move |_| Some(func() as _));
 	}
 
 	pub_fn_wm_ret0_param! { wm_r_button_dbl_clk, co::WM::RBUTTONDBLCLK, wm::RButtonDblClk,
@@ -1038,8 +1043,8 @@ impl WindowEvents {
 	pub_fn_wm_retbool_param! { wm_set_cursor, co::WM::SETCURSOR, wm::SetCursor,
 		/// [`WM_SETCURSOR`](crate::msg::wm::SetCursor) message.
 		///
-		/// Sent to a window if the mouse causes the cursor to move within a window
-		/// and mouse input is not captured.
+		/// Sent to a window if the mouse causes the cursor to move within a
+		/// window and mouse input is not captured.
 	}
 
 	pub_fn_wm_ret0_param! { wm_set_focus, co::WM::SETFOCUS, wm::SetFocus,
@@ -1067,15 +1072,14 @@ impl WindowEvents {
 	/// the large icon in the Alt+TAB dialog box, and the small icon in the
 	/// window caption.
 	pub fn wm_set_icon<F>(&self, func: F)
-		where F: FnMut(wm::SetIcon) -> Option<HICON> + 'static,
+		where F: Fn(wm::SetIcon) -> Option<HICON> + 'static,
 	{
-		self.add_msg(co::WM::SETICON, {
-			let mut func = func;
-			move |p| Some(
+		self.add_msg(co::WM::SETICON, move |p|
+			Some(
 				func(wm::SetIcon::from_generic_wm(p))
 					.map(|h| h.ptr as _).unwrap_or_default(),
 			)
-		});
+		);
 	}
 
 	pub_fn_wm_ret0_param! { wm_show_window, co::WM::SHOWWINDOW, wm::ShowWindow,
@@ -1121,16 +1125,16 @@ impl WindowEvents {
 		/// [`WM_STYLECHANGED`](crate::msg::wm::StyleChanged) message.
 		///
 		/// Sent to a window after the
-		/// [`SetWindowLongPtr`](crate::HWND::SetWindowLongPtr) function has
-		/// changed one or more of the window's styles.
+		/// [`HWND::SetWindowLongPtr`](crate::HWND::SetWindowLongPtr) function
+		/// has changed one or more of the window's styles.
 	}
 
 	pub_fn_wm_ret0_param! { wm_style_changing, co::WM::STYLECHANGING, wm::StyleChanging,
 		/// [`WM_STYLECHANGING`](crate::msg::wm::StyleChanging) message.
 		///
 		/// Sent to a window when the
-		/// [`SetWindowLongPtr`](crate::HWND::SetWindowLongPtr) function is
-		/// about to change one or more of the window's styles.
+		/// [`HWND::SetWindowLongPtr`](crate::HWND::SetWindowLongPtr) function
+		/// is about to change one or more of the window's styles.
 	}
 
 	pub_fn_wm_ret0_param! { wm_sys_char, co::WM::SYSCHAR, wm::SysChar,
@@ -1213,8 +1217,8 @@ impl WindowEvents {
 		///
 		/// Sent to a window whose size, position, or place in the Z order has
 		/// changed as a result of a call to the
-		/// [`SetWindowPos`](crate::HWND::SetWindowPos) function or another
-		/// window-management function.
+		/// [`HWND::SetWindowPos`](crate::HWND::SetWindowPos) function or
+		/// another window-management function.
 	}
 
 	pub_fn_wm_ret0_param! { wm_window_pos_changing, co::WM::WINDOWPOSCHANGING, wm::WindowPosChanging,
@@ -1222,8 +1226,8 @@ impl WindowEvents {
 		///
 		/// Sent to a window whose size, position, or place in the Z order is
 		/// about to change as a result of a call to the
-		/// [`SetWindowPos`](crate::HWND::SetWindowPos) function or another
-		/// window-management function.
+		/// [`HWND::SetWindowPos`](crate::HWND::SetWindowPos) function or
+		/// another window-management function.
 	}
 
 	pub_fn_wm_ret0_param! { wm_x_button_dbl_clk, co::WM::XBUTTONDBLCLK, wm::XButtonDblClk,
