@@ -6,13 +6,6 @@ pub_struct_handle_gdi! {
 	HBITMAP
 }
 
-pub_struct_handle_gdi! {
-	/// Handle to a
-	/// [pen](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hpen)
-	/// GDI object.
-	HPEN
-}
-
 pub_struct_handle_closeable! {
 	/// Handle to an
 	/// [event](https://docs.microsoft.com/en-us/windows/win32/api/synchapi/nf-synchapi-createeventw).
@@ -20,6 +13,26 @@ pub_struct_handle_closeable! {
 	HEVENT
 }
 
+pub_struct_handle! {
+	/// Handle to a
+	/// [resource](https://docs.microsoft.com/en-us/windows/win32/api/libloaderapi/nf-libloaderapi-findresourcew).
+	/// Originally just a `HANDLE`.
+	///
+	/// For an example, see
+	/// [`HINSTANCE::LockResource`](crate::HINSTANCE::LockResource).
+	HRSRC
+}
+
+pub_struct_handle! {
+	/// Handle to a resource
+	/// [memory block](https://docs.microsoft.com/en-us/windows/win32/api/libloaderapi/nf-libloaderapi-loadresource).
+	/// Originally just an `HGLOBAL`.
+	///
+	/// For an example, see
+	/// [`HINSTANCE::LockResource`](crate::HINSTANCE::LockResource).
+	HRSRCMEM
+}
+
 pub_struct_handle! {
 	/// Handle to an
 	/// [tree view item](https://docs.microsoft.com/en-us/windows/win32/controls/tree-view-controls).
