@@ -1,15 +1,16 @@
 #![allow(non_snake_case)]
 
-use crate::aliases::{SUBCLASSPROC, TIMERPROC, WinResult, WNDENUMPROC};
+use crate::aliases::{SUBCLASSPROC, TIMERPROC, WinResult};
 use crate::co;
-use crate::enums::{AtomStr, HwndPlace, IdMenu, IdPos, IdTdicon};
-use crate::ffi::{BOOL, comctl32, user32, uxtheme};
+use crate::enums::{AtomStr, HwndPlace, IdMenu, IdPos, IdTdiconStr};
+use crate::ffi::{BOOL, comctl32, shell32, user32, uxtheme};
 use crate::funcs::{GetLastError, SetLastError};
 use crate::handles::{HACCEL, HDC, HINSTANCE, HMENU, HRGN, HTHEME};
 use crate::msg::MsgSend;
 use crate::privs::{bool_to_winresult, hr_to_winresult};
 use crate::structs::{
 	ALTTABINFO,
+	MENUBARINFO,
 	MSG,
 	PAINTSTRUCT,
 	POINT,
@@ -18,7 +19,7 @@ use crate::structs::{
 	WINDOWINFO,
 	WINDOWPLACEMENT,
 };
-use crate::WString;
+use crate::various::WString;
 
 pub_struct_handle! {
 	/// Handle to a
@@ -27,8 +28,10 @@ pub_struct_handle! {
 }
 
 impl HWND {
-	/// For some specific functions, represents all top-level windows.
-	pub const BROADCAST: Self = Self { ptr: std::ptr::null_mut() };
+	/// Represents all top-level windows in
+	/// [`HWND::PostMessage`](crate::HWND::PostMessage) and
+	/// [`HWND::SendMessage`](crate::HWND::SendMessage).
+	pub const BROADCAST: Self = Self { ptr: 0xffff as _ };
 
 	/// [`GetWindowLongPtr`](crate::HWND::GetWindowLongPtr) wrapper to retrieve
 	/// the window [`HINSTANCE`](crate::HINSTANCE).
@@ -48,8 +51,8 @@ impl HWND {
 	/// [`BeginPaint`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-beginpaint)
 	/// method.
 	///
-	/// **Note:** Must be paired with an [`EndPaint`](crate::HWND::EndPaint)
-	/// call.
+	/// **Note:** Must be paired with an
+	/// [`HWND::EndPaint`](crate::HWND::EndPaint) call.
 	///
 	/// # Examples
 	///
@@ -202,6 +205,12 @@ impl HWND {
 		unsafe { user32::DestroyWindow(self.ptr); }
 	}
 
+	/// [`DrawMenuBar`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-drawmenubar)
+	/// method.
+	pub fn DrawMenuBar(self) -> WinResult<()> {
+		bool_to_winresult(unsafe { user32::DrawMenuBar(self.ptr) })
+	}
+
 	/// [`EnableWindow`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-enablewindow)
 	/// method.
 	pub fn EnableWindow(self, bEnable: bool) -> bool {
@@ -223,20 +232,6 @@ impl HWND {
 	/// [`EnumChildWindows`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-enumchildwindows)
 	/// method.
 	///
-	/// This method can be more performant than
-	/// [`EnumChildWindowsVec`](crate::HWND::EnumChildWindowsVec), which passes
-	/// through all children and allocates a `Vec`. However, it has the
-	/// inconvenient of the manual function pointer.
-	pub fn EnumChildWindows(self, lpEnumFunc: WNDENUMPROC, lParam: isize) {
-		unsafe {
-			user32::EnumChildWindows(self.ptr, lpEnumFunc as _, lParam);
-		}
-	}
-
-	/// A more convenient [`EnumChildWindows`](crate::HWND::EnumChildWindows),
-	/// which returns a `Vec` with the handles of all child windows, instead of
-	/// taking a function pointer.
-	///
 	/// # Examples
 	///
 	/// ```rust,ignore
@@ -244,24 +239,27 @@ impl HWND {
 	///
 	/// let my_hwnd: HWND; // initialized somewhere
 	///
-	/// for hchild in my_hwnd.EnumChildWindowsVec() {
-	///     println!("HWND: {}", hchild);
-	/// }
+	/// my_hwnd.EnumChildWindows(|hchild: HWND| -> bool {
+	///     println!("Child HWND: {}", hchild);
+	///     true
+	/// });
 	/// ```
-	pub fn EnumChildWindowsVec(self) -> Vec<HWND> {
-		let mut hchildren = Vec::default();
-		self.EnumChildWindows(
-			Self::EnumChildWindowsVecProc,
-			&mut hchildren as *mut Vec<_> as _, // pass pointer to Vec
-		);
-		hchildren
-	}
-	extern "system" fn EnumChildWindowsVecProc(
-		hchild: HWND, lparam: isize) -> BOOL
+	pub fn EnumChildWindows<F>(self, func: F)
+		where F: Fn(HWND) -> bool,
 	{
-		let hchildren = unsafe { &mut *(lparam as *mut Vec<HWND>) }; // retrieve pointer to Vec
-		hchildren.push(hchild);
-		true as _
+		unsafe {
+			user32::EnumChildWindows(
+				self.ptr,
+				Self::EnumChildProc::<F> as _, // https://redd.it/npehj9
+				&func as *const _ as _,
+			);
+		}
+	}
+	extern "system" fn EnumChildProc<F>(hwnd: HWND, lParam: isize) -> BOOL
+		where F: Fn(HWND) -> bool,
+	{
+		let func = unsafe { &*(lParam as *const F) };
+		func(hwnd) as _
 	}
 
 	/// [`FindWindow`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-findwindoww)
@@ -368,8 +366,8 @@ impl HWND {
 	/// [`GetDC`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getdc)
 	/// method.
 	///
-	/// **Note:** Must be paired with a [`ReleaseDC`](crate::HWND::ReleaseDC)
-	/// call.
+	/// **Note:** Must be paired with an
+	/// [`HWND::ReleaseDC`](crate::HWND::ReleaseDC) call.
 	pub fn GetDC(self) -> WinResult<HDC> {
 		unsafe { user32::GetDC(self.ptr).as_mut() }
 			.map(|ptr| HDC { ptr })
@@ -386,20 +384,20 @@ impl HWND {
 
 	/// [`GetDlgCtrlID`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getdlgctrlid)
 	/// method.
-	pub fn GetDlgCtrlID(self) -> WinResult<i32> {
+	pub fn GetDlgCtrlID(self) -> WinResult<u16> {
 		match unsafe { user32::GetDlgCtrlID(self.ptr) } {
 			0 => match GetLastError() {
 				co::ERROR::SUCCESS => Ok(0), // actual ID is zero
 				err => Err(err),
 			},
-			id => Ok(id),
+			id => Ok(id as _),
 		}
 	}
 
 	/// [`GetDlgItem`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getdlgitem)
 	/// method.
-	pub fn GetDlgItem(self, nIDDlgItem: i32) -> WinResult<HWND> {
-		unsafe { user32::GetDlgItem(self.ptr, nIDDlgItem).as_mut() }
+	pub fn GetDlgItem(self, nIDDlgItem: u16) -> WinResult<HWND> {
+		unsafe { user32::GetDlgItem(self.ptr, nIDDlgItem as _).as_mut() }
 			.map(|ptr| Self { ptr })
 			.ok_or_else(|| GetLastError())
 	}
@@ -418,6 +416,47 @@ impl HWND {
 			.map(|ptr| Self { ptr })
 	}
 
+	/// [`GetMenu`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmenu)
+	/// method.
+	pub fn GetMenu(self) -> Option<HMENU> {
+		unsafe { user32::GetMenu(self.ptr).as_mut() }
+			.map(|ptr| HMENU { ptr })
+	}
+
+	/// [`GetMenuBarInfo`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmenubarinfo)
+	/// method.
+	pub fn GetMenuBarInfo(self,
+		idObject: co::OBJID, idItem: u32, pmbi: &mut MENUBARINFO) -> WinResult<()>
+	{
+		bool_to_winresult(
+			unsafe {
+				user32::GetMenuBarInfo(
+					self.ptr,
+					idObject.0 as _,
+					idItem as _,
+					pmbi as *mut _ as _,
+				)
+			},
+		)
+	}
+
+	/// [`GetMenuItemRect`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmenuitemrect)
+	/// method.
+	pub fn GetMenuItemRect(self,
+		hMenu: HMENU, uItemPos: u32, lprcItem: &mut RECT) -> WinResult<()>
+	{
+		bool_to_winresult(
+			unsafe {
+				user32::GetMenuItemRect(
+					self.ptr,
+					hMenu.ptr,
+					uItemPos,
+					lprcItem as *mut _ as _,
+				)
+			},
+		)
+	}
+
 	/// [`GetNextDlgGroupItem`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getnextdlggroupitem)
 	/// method.
 	pub fn GetNextDlgGroupItem(self,
@@ -473,6 +512,20 @@ impl HWND {
 		}
 	}
 
+	/// [`GetShellWindow`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getshellwindow)
+	/// static method.
+	pub fn GetShellWindow() -> Option<HWND> {
+		unsafe { user32::GetShellWindow().as_mut() }
+			.map(|ptr| Self { ptr })
+	}
+
+	/// [`GetSystemMenu`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getsystemmenu)
+	/// method.
+	pub fn GetSystemMenu(self, bRevert: bool) -> Option<HMENU> {
+		unsafe { user32::GetSystemMenu(self.ptr, bRevert as _).as_mut() }
+			.map(|ptr| HMENU { ptr })
+	}
+
 	/// [`GetUpdateRgn`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getupdatergn)
 	/// method.
 	pub fn GetUpdateRgn(self, hRgn: HRGN, bErase: bool) -> WinResult<co::REGION> {
@@ -493,8 +546,8 @@ impl HWND {
 	/// [`GetWindowDC`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getwindowdc)
 	/// method.
 	///
-	/// **Note:** Must be paired with a [`ReleaseDC`](crate::HWND::ReleaseDC)
-	/// call.
+	/// **Note:** Must be paired with an
+	/// [`HWND::ReleaseDC`](crate::HWND::ReleaseDC) call.
 	pub fn GetWindowDC(self) -> WinResult<HDC> {
 		unsafe { user32::GetWindowDC(self.ptr).as_mut() }
 			.map(|ptr| HDC { ptr })
@@ -577,48 +630,29 @@ impl HWND {
 	/// [`GetWindowText`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getwindowtextw)
 	/// method.
 	///
-	/// The passed buffer will be automatically allocated with
-	/// [`GetWindowTextLength`](crate::HWND::GetWindowTextLength).
-	///
-	/// This method can be more performant than
-	/// [`GetWindowTextStr`](crate::HWND::GetWindowTextStr) because the buffer
-	/// can be reused, avoiding multiple allocations. However, it has the
-	/// inconvenient of the manual conversion from [`WString`](crate::WString)
-	/// to `String`.
-	///
-	/// # Examples
-	///
 	/// ```rust,ignore
-	/// use winsafe::{HWND, WString};
+	/// use winsafe::HWND;
 	///
 	/// let my_hwnd: HWND; // initialized somewhere
 	///
-	/// let mut buf = WString::new();
-	/// my_hwnd.GetWindowText(&mut buf).unwrap();
-	/// println!("Text: {}", buf.to_string());
+	/// let text = my_hwnd.GetWindowText().unwrap();
+	/// println!("Text: {}", text);
 	/// ```
-	pub fn GetWindowText(self, buf: &mut WString) -> WinResult<i32> {
-		match self.GetWindowTextLength()? {
-			0 => { // window has no text, simply clear buffer
-				buf.realloc_buffer(0);
-				Ok(0)
-			},
-			len => {
-				buf.realloc_buffer(len as usize + 1); // plus terminating null
+	pub fn GetWindowText(self) -> WinResult<String> {
+		let len = self.GetWindowTextLength()?;
+		if len == 0 {
+			return Ok(String::default()); // window has no text
+		}
 
-				match unsafe {
-					user32::GetWindowTextW(self.ptr, buf.as_mut_ptr(), len + 1)
-				} {
-					0 => match GetLastError() {
-						co::ERROR::SUCCESS => {
-							buf.realloc_buffer(0); // no chars copied for some reason
-							Ok(0)
-						},
-						err => Err(err),
-					},
-					nCopied => Ok(nCopied), // return number of copied chars without terminating null
-				}
+		let mut buf = WString::new_alloc_buffer(len as usize + 1); // plus terminating null
+		match unsafe {
+			user32::GetWindowTextW(self.ptr, buf.as_mut_ptr(), len + 1)
+		} {
+			0 => match GetLastError() {
+				co::ERROR::SUCCESS => Ok(String::default()), // no chars copied for some reason
+				err => Err(err),
 			},
+			_ => Ok(buf.to_string()),
 		}
 	}
 
@@ -635,23 +669,10 @@ impl HWND {
 		}
 	}
 
-	/// A more convenient [`GetWindowText`](crate::HWND::GetWindowText), which
-	/// directly returns a `String` instead of requiring an external buffer.
-	///
-	/// # Examples
-	///
-	/// ```rust,ignore
-	/// use winsafe::HWND;
-	///
-	/// let my_hwnd: HWND; // initialized somewhere
-	///
-	/// let text = my_hwnd.GetWindowTextStr().unwrap();
-	/// println!("Text: {}", text);
-	/// ```
-	pub fn GetWindowTextStr(self) -> WinResult<String> {
-		let mut buf = WString::default();
-		self.GetWindowText(&mut buf)?;
-		Ok(buf.to_string())
+	/// [`GetWindowThreadProcessId`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getwindowthreadprocessid)
+	/// method.
+	pub fn GetWindowThreadProcessId(self) -> u32 {
+		unsafe { user32::GetWindowThreadProcessId(self.ptr, std::ptr::null_mut()) }
 	}
 
 	/// [`HiliteMenuItem`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-hilitemenuitem)
@@ -757,6 +778,14 @@ impl HWND {
 		bool_to_winresult(unsafe { user32::KillTimer(self.ptr, uIDEvent) })
 	}
 
+	/// [`LogicalToPhysicalPoint`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-logicaltophysicalpoint)
+	/// method.
+	pub fn LogicalToPhysicalPoint(self, lpPoint: *mut POINT) -> WinResult<()> {
+		bool_to_winresult(
+			unsafe { user32::LogicalToPhysicalPoint(self.ptr, lpPoint as _) },
+		)
+	}
+
 	/// [`MapDialogRect`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-mapdialogrect)
 	/// method.
 	pub fn MapDialogRect(self, lpRect: &mut RECT) -> WinResult<()> {
@@ -838,8 +867,8 @@ impl HWND {
 	/// [`OpenThemeData`](https://docs.microsoft.com/en-us/windows/win32/api/uxtheme/nf-uxtheme-openthemedata)
 	/// method.
 	///
-	/// **Note:** Must be paired with a
-	/// [`CloseThemeData`](crate::HTHEME::CloseThemeData) call.
+	/// **Note:** Must be paired with an
+	/// [`HTHEME::CloseThemeData`](crate::HTHEME::CloseThemeData) call.
 	pub fn OpenThemeData(self, pszClassList: &str) -> Option<HTHEME> {
 		unsafe {
 			uxtheme::OpenThemeData(
@@ -978,7 +1007,7 @@ impl HWND {
 	///
 	/// # Examples
 	///
-	/// Sending a [`LVM_SETITEM`](crate::msg::lvm::SetItem) list view message,
+	/// Sending a [`lvm::SetItem`](crate::msg::lvm::SetItem) list view message,
 	/// which demands a reference to an [`LVITEM`](crate::LVITEM) object:
 	///
 	/// ```rust,ignore
@@ -1197,6 +1226,33 @@ impl HWND {
 		)
 	}
 
+	/// [`ShellExecute`](https://docs.microsoft.com/en-us/windows/win32/api/shellapi/nf-shellapi-shellexecutew)
+	/// method.
+	pub fn ShellExecute(self,
+		lpOperation: &str,
+		lpFile: &str,
+		lpParameters: Option<&str>,
+		lpDirectory: Option<&str>,
+		nShowCmd: co::SW) -> Result<HINSTANCE, co::SE_ERR>
+	{
+		let ret = unsafe {
+			shell32::ShellExecuteW(
+				self.ptr,
+				WString::from_str(lpOperation).as_ptr(),
+				WString::from_str(lpFile).as_ptr(),
+				lpParameters.map_or(std::ptr::null(), |lp| WString::from_str(lp).as_ptr()),
+				lpDirectory.map_or(std::ptr::null(), |lp| WString::from_str(lp).as_ptr()),
+				nShowCmd.0,
+			)
+		};
+
+		if ret <= 32 as _ {
+			Err(co::SE_ERR(ret as _))
+		} else {
+			Ok(HINSTANCE { ptr: ret as _ })
+		}
+	}
+
 	/// [`ShowCaret`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-showcaret)
 	/// method.
 	pub fn ShowCaret(self) -> WinResult<()> {
@@ -1212,6 +1268,9 @@ impl HWND {
 	/// [`TaskDialog`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-taskdialog)
 	/// method.
 	///
+	/// If you need more customization, consider the
+	/// [`TaskDialogIndirect`](crate::TaskDialogIndirect) function.
+	///
 	/// # Examples
 	///
 	/// An information message with just an OK button:
@@ -1257,10 +1316,10 @@ impl HWND {
 		pszMainInstruction: Option<&str>,
 		pszContent: Option<&str>,
 		dwCommonButtons: co::TDCBF,
-		pszIcon: IdTdicon) -> WinResult<co::DLGID>
+		pszIcon: IdTdiconStr) -> WinResult<co::DLGID>
 	{
 		// https://weblogs.asp.net/kennykerr/Windows-Vista-for-Developers-_1320_-Part-2-_1320_-Task-Dialogs-in-Depth
-		let mut pnButton = co::DLGID::CANCEL;
+		let mut pnButton: i32 = 0;
 		hr_to_winresult(
 			unsafe {
 				comctl32::TaskDialog(
@@ -1271,10 +1330,10 @@ impl HWND {
 					WString::from_opt_str(pszContent).as_ptr(),
 					dwCommonButtons.0,
 					pszIcon.as_ptr(),
-					&mut pnButton.0,
+					&mut pnButton,
 				)
 			},
-		).map(|_| pnButton)
+		).map(|_| co::DLGID(pnButton as _))
 	}
 
 	/// [`TranslateAccelerator`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-translateacceleratorw)
