@@ -22,12 +22,14 @@ mod hinstance;
 mod hkey;
 mod hlocal;
 mod hmenu;
+mod hpen;
 mod hpipe;
 mod hprocess;
 mod hprocesslist;
 mod hrgn;
 mod htheme;
 mod hthread;
+mod hupdatersrc;
 mod hwnd;
 
 pub use any_handles::*;
@@ -49,10 +51,12 @@ pub use hinstance::HINSTANCE;
 pub use hkey::HKEY;
 pub use hlocal::HLOCAL;
 pub use hmenu::HMENU;
+pub use hpen::HPEN;
 pub use hpipe::HPIPE;
 pub use hprocess::HPROCESS;
 pub use hprocesslist::HPROCESSLIST;
 pub use hrgn::HRGN;
 pub use htheme::HTHEME;
 pub use hthread::HTHREAD;
+pub use hupdatersrc::HUPDATERSRC;
 pub use hwnd::HWND;
