@@ -6,6 +6,7 @@ use crate::aliases::WinResult;
 use crate::co;
 use crate::handles::HICON;
 use crate::msg::{MsgSend, WndMsg};
+use crate::msg::macros::zero_as_err;
 
 /// [`STM_GETICON`](https://docs.microsoft.com/en-us/windows/win32/controls/stm-geticon)
 /// message, which has no parameters.
@@ -17,10 +18,7 @@ impl MsgSend for GetIcon {
 	type RetType = WinResult<HICON>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			p => Ok(HICON { ptr: p as _ }),
-		}
+		zero_as_err(v).map(|p| HICON { ptr: p as _ })
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -44,10 +42,7 @@ impl MsgSend for SetIcon {
 	type RetType = WinResult<HICON>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			p => Ok(HICON { ptr: p as _ }),
-		}
+		zero_as_err(v).map(|p| HICON { ptr: p as _ })
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
