@@ -15,12 +15,14 @@ use crate::enums::{
 use crate::funcs::{HIBYTE, HIWORD, LOBYTE, LOWORD, MAKEDWORD, MAKEWORD};
 use crate::handles::{HBRUSH, HDC, HDROP, HFONT, HICON, HMENU, HRGN, HWND};
 use crate::msg::{MsgSend, MsgSendRecv, WndMsg};
-use crate::msg::macros::{lp_to_point, point_to_lp};
+use crate::msg::macros::{lp_to_point, point_to_lp, zero_as_none};
 use crate::privs::FAPPCOMMAND_MASK;
 use crate::structs::{
 	CREATESTRUCT,
+	DELETEITEMSTRUCT,
 	HELPINFO,
 	MINMAXINFO,
+	MSG,
 	NMHDR,
 	POINT,
 	RECT,
@@ -142,6 +144,38 @@ pub_struct_msg_empty_handleable! { CancelMode, co::WM::CANCELMODE,
 	/// [`WM_CANCELMODE`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-cancelmode)
 }
 
+/// [`WM_CAPTURECHANGED`](https://docs.microsoft.com/en-us/windows/win32/inputdev/wm-capturechanged)
+/// message parameters.
+///
+/// Return type: `()`.
+pub struct CaptureChanged {
+	pub hwnd_gaining_mouse: HWND,
+}
+
+impl MsgSend for CaptureChanged {
+	type RetType = ();
+
+	fn convert_ret(&self, _: isize) -> Self::RetType {
+		()
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::CAPTURECHANGED,
+			wparam: self.hwnd_gaining_mouse.ptr as _,
+			lparam: 0,
+		}
+	}
+}
+
+impl MsgSendRecv for CaptureChanged {
+	fn from_generic_wm(p: WndMsg) -> Self {
+		Self {
+			hwnd_gaining_mouse: HWND { ptr: p.wparam as _ },
+		}
+	}
+}
+
 pub_struct_msg_empty_handleable! { ChildActivate, co::WM::CHILDACTIVATE,
 	/// [`WM_CHILDACTIVATE`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-childactivate)
 }
@@ -298,6 +332,40 @@ pub_struct_msg_char! { DeadChar, co::WM::DEADCHAR,
 	/// [`WM_DEADCHAR`](https://docs.microsoft.com/en-us/windows/win32/inputdev/wm-deadchar)
 }
 
+/// [`WM_DELETEITEM`](https://docs.microsoft.com/en-us/windows/win32/controls/wm-deleteitem)
+/// message parameters.
+///
+/// Return type: `()`.
+pub struct DeleteItem<'a> {
+	pub control_id: u16,
+	pub deleteitemstruct: &'a DELETEITEMSTRUCT,
+}
+
+impl<'a> MsgSend for DeleteItem<'a> {
+	type RetType = ();
+
+	fn convert_ret(&self, _: isize) -> Self::RetType {
+		()
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::DELETEITEM,
+			wparam: self.control_id as _,
+			lparam: self.deleteitemstruct as *const _ as _,
+		}
+	}
+}
+
+impl<'a> MsgSendRecv for DeleteItem<'a> {
+	fn from_generic_wm(p: WndMsg) -> Self {
+		Self {
+			control_id: p.wparam as _,
+			deleteitemstruct: unsafe { &mut *(p.lparam as *mut _) },
+		}
+	}
+}
+
 pub_struct_msg_empty_handleable! { Destroy, co::WM::DESTROY,
 	/// [`WM_DESTROY`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-destroy)
 }
@@ -542,6 +610,43 @@ pub_struct_msg_empty_handleable! { ExitSizeMove, co::WM::EXITSIZEMOVE,
 	/// [`WM_EXITSIZEMOVE`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-exitsizemove)
 }
 
+/// [`WM_GETDLGCODE`](https://docs.microsoft.com/en-us/windows/win32/dlgbox/wm-getdlgcode)
+/// message parameters.
+///
+/// Return type: `co::DLGC`.
+pub struct GetDlgCode<'a> {
+	pub vkey_code: co::VK,
+	pub msg: Option<&'a mut MSG>,
+}
+
+impl<'a> MsgSend for GetDlgCode<'a> {
+	type RetType = co::DLGC;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		co::DLGC(v as _)
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::GETDLGCODE,
+			wparam: self.vkey_code.0 as _,
+			lparam: self.msg.as_ref().map_or(0, |m| m as *const _ as _),
+		}
+	}
+}
+
+impl<'a> MsgSendRecv for GetDlgCode<'a> {
+	fn from_generic_wm(p: WndMsg) -> Self {
+		Self {
+			vkey_code: co::VK(p.wparam as _),
+			msg: match p.lparam {
+				0 => None,
+				ptr => Some(unsafe { &mut *(ptr as *mut _) })
+			},
+		}
+	}
+}
+
 /// [`WM_GETFONT`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-getfont)
 /// message, which has no parameters.
 ///
@@ -552,10 +657,7 @@ impl MsgSend for GetFont {
 	type RetType = Option<HFONT>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => None,
-			p => Some(HFONT { ptr: p as _ }),
-		}
+		zero_as_none(v).map(|p| HFONT { ptr: p as _ })
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -583,10 +685,7 @@ impl MsgSend for GetHMenu {
 	type RetType = Option<HMENU>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => None,
-			p => Some(HMENU { ptr: p as _ }),
-		}
+		zero_as_none(v).map(|p| HMENU { ptr: p as _ })
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -982,6 +1081,10 @@ pub_struct_msg_button! { MouseHover, co::WM::MOUSEHOVER,
 	/// [`WM_MOUSEHOVER`](https://docs.microsoft.com/en-us/windows/win32/inputdev/wm-mousehover)
 }
 
+pub_struct_msg_empty_handleable! { MouseLeave, co::WM::MOUSELEAVE,
+	/// [`WM_MOUSELEAVE`](https://docs.microsoft.com/en-us/windows/win32/inputdev/wm-mouseleave)
+}
+
 pub_struct_msg_button! { MouseMove, co::WM::MOUSEMOVE,
 	/// [`WM_MOUSEMOVE`](https://docs.microsoft.com/en-us/windows/win32/inputdev/wm-mousemove)
 }
@@ -1211,11 +1314,11 @@ impl MsgSend for NextDlgCtl {
 			msg_id: co::WM::NEXTDLGCTL,
 			wparam: match self.hwnd_focus {
 				HwndFocus::Hwnd(hctl) => hctl.ptr as _,
-				HwndFocus::FocusPrev(prev) => prev as _,
+				HwndFocus::FocusNext(next) => if next { 0 } else { 1 },
 			},
 			lparam: MAKEDWORD(match self.hwnd_focus {
 				HwndFocus::Hwnd(_) => 1,
-				HwndFocus::FocusPrev(_) => 0,
+				HwndFocus::FocusNext(_) => 0,
 			}, 0) as _,
 		}
 	}
@@ -1226,7 +1329,7 @@ impl MsgSendRecv for NextDlgCtl {
 		Self {
 			hwnd_focus: match p.wparam {
 				1 => HwndFocus::Hwnd(HWND { ptr: p.wparam as _ }),
-				_ => HwndFocus::FocusPrev(p.wparam != 0),
+				_ => HwndFocus::FocusNext(p.wparam == 0),
 			},
 		}
 	}
@@ -1487,10 +1590,7 @@ impl MsgSend for SetIcon {
 	type RetType = Option<HICON>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => None,
-			p => Some(HICON { ptr: p as _ }),
-		}
+		zero_as_none(v).map(|p| HICON { ptr: p as _ })
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
