@@ -5,11 +5,16 @@
 use std::marker::PhantomData;
 
 use crate::co;
-use crate::enums::HtreeitemTvi;
-use crate::handles::{HDC, HIMAGELIST, HTREEITEM, HWND};
-use crate::privs::{L_MAX_URL_LENGTH, MAX_LINKID_TEXT};
+use crate::enums::{BmpIdbRes, IdStr, IndexStr, TreeitemTvi};
+use crate::handles::{HBITMAP, HDC, HIMAGELIST, HINSTANCE, HTREEITEM, HWND};
+use crate::privs::{
+	HINST_COMMCTRL,
+	IS_INTRESOURCE,
+	L_MAX_URL_LENGTH,
+	MAX_LINKID_TEXT,
+};
 use crate::structs::{COLORREF, NMHDR, POINT, RECT, SIZE, SYSTEMTIME};
-use crate::WString;
+use crate::various::WString;
 
 /// [`BUTTON_IMAGELIST`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-button_imagelist)
 /// struct.
@@ -83,7 +88,7 @@ pub struct LITEM {
 	szUrl: [u16; L_MAX_URL_LENGTH],
 }
 
-impl_default_zero!(LITEM);
+impl_default!(LITEM);
 
 impl LITEM {
 	pub_fn_string_arr_get_set!(szID, set_szID);
@@ -105,13 +110,14 @@ pub struct LVCOLUMN<'a> {
 	pub cxMin: i32,
 	pub cxDefault: i32,
 	pub cxIdeal: i32,
-	m_pszText: PhantomData<&'a u16>,
+
+	pszText_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(LVCOLUMN, 'a);
+impl_default!(LVCOLUMN, 'a);
 
 impl<'a> LVCOLUMN<'a> {
-	pub_fn_string_buf_get_set!(pszText, set_pszText, cchTextMax);
+	pub_fn_string_buf_get_set!('a, pszText, set_pszText, cchTextMax);
 }
 
 /// [`LVFINDINFO`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-lvfindinfow)
@@ -123,10 +129,11 @@ pub struct LVFINDINFO<'a> {
 	pub lParam: isize,
 	pub pt: POINT,
 	pub vkDirection: co::VK_DIR,
-	m_psz: PhantomData<&'a u16>,
+
+	psz_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(LVFINDINFO, 'a);
+impl_default!(LVFINDINFO, 'a);
 
 impl<'a> LVFINDINFO<'a> {
 	pub_fn_string_ptr_get_set!('a, psz, set_psz);
@@ -163,13 +170,23 @@ pub struct LVITEM<'a> {
 	pub puColumns: *mut i32,
 	pub piColFmt: *mut co::LVCFMT_I,
 	pub iGroup: i32,
-	m_pszText: PhantomData<&'a u16>,
+
+	pszText_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(LVITEM, 'a);
+impl_default!(LVITEM, 'a);
 
 impl<'a> LVITEM<'a> {
-	pub_fn_string_buf_get_set!(pszText, set_pszText, cchTextMax);
+	pub_fn_string_buf_get_set!('a, pszText, set_pszText, cchTextMax);
+}
+
+/// [`LVITEMINDEX`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-lvitemindex)
+/// struct.
+#[repr(C)]
+#[derive(Default, Copy, Clone, Eq, PartialEq)]
+pub struct LVITEMINDEX {
+	pub iItem: i32,
+	pub iGroup: i32,
 }
 
 /// [`NMBCDROPDOWN`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmbcdropdown)
@@ -229,10 +246,11 @@ pub struct NMDATETIMEFORMAT<'a> {
 	pub st: SYSTEMTIME,
 	pszDisplay: *mut u16,
 	szDisplay: [u16; 64], // used as a buffer to pszDisplay
-	m_pszFormat: PhantomData<&'a u16>,
+
+	pszFormat_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(NMDATETIMEFORMAT, 'a);
+impl_default!(NMDATETIMEFORMAT, 'a);
 
 impl<'a> NMDATETIMEFORMAT<'a> {
 	pub_fn_string_ptr_get_set!('a, pszFormat, set_pszFormat);
@@ -255,10 +273,11 @@ pub struct NMDATETIMEFORMATQUERY<'a> {
 	pub nmhdr: NMHDR,
 	pszFormat: *mut u16,
 	pub szMax: SIZE,
-	m_pszFormat: PhantomData<&'a u16>,
+
+	pszFormat_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(NMDATETIMEFORMATQUERY, 'a);
+impl_default!(NMDATETIMEFORMATQUERY, 'a);
 
 impl<'a> NMDATETIMEFORMATQUERY<'a> {
 	pub_fn_string_ptr_get_set!('a, pszFormat, set_pszFormat);
@@ -266,18 +285,17 @@ impl<'a> NMDATETIMEFORMATQUERY<'a> {
 
 /// [`NMDATETIMESTRING`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmdatetimestringw)
 /// struct.
-///
-/// You cannot directly instantiate this object.
 #[repr(C)]
 pub struct NMDATETIMESTRING<'a> {
 	pub nmhdr: NMHDR,
 	pszUserString: *mut u16,
 	pub st: SYSTEMTIME,
 	pub dwFlags: co::GDT,
-	m_pszUserString: PhantomData<&'a u16>,
+
+	pszUserString_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(NMDATETIMESTRING, 'a);
+impl_default!(NMDATETIMESTRING, 'a);
 
 impl<'a> NMDATETIMESTRING<'a> {
 	pub_fn_string_ptr_get_set!('a, pszUserString, set_pszUserString);
@@ -291,10 +309,11 @@ pub struct NMDATETIMEWMKEYDOWN<'a> {
 	pub nVirtKey: i32,
 	pszFormat: *mut u16,
 	pub st: SYSTEMTIME,
-	m_pszFormat: PhantomData<&'a u16>,
+
+	pszFormat_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(NMDATETIMEWMKEYDOWN, 'a);
+impl_default!(NMDATETIMEWMKEYDOWN, 'a);
 
 impl<'a> NMDATETIMEWMKEYDOWN<'a> {
 	pub_fn_string_ptr_get_set!('a, pszFormat, set_pszFormat);
@@ -302,26 +321,20 @@ impl<'a> NMDATETIMEWMKEYDOWN<'a> {
 
 /// [`NMDAYSTATE`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmdaystate)
 /// struct.
-///
-/// You cannot directly instantiate this object.
 #[repr(C)]
-pub struct NMDAYSTATE {
+pub struct NMDAYSTATE<'a> {
 	pub nmhdr: NMHDR,
 	pub stStart: SYSTEMTIME,
 	cDayState: i32,
 	prgDayState: *mut u32,
+
+	prgDayState_: PhantomData<&'a mut u32>,
 }
 
-impl NMDAYSTATE {
-	/// Returns the `prgDayState` field.
-	pub fn prgDayState(&mut self) -> &mut [u32] {
-		unsafe {
-			std::slice::from_raw_parts_mut(
-				self.prgDayState,
-				self.cDayState as _,
-			)
-		}
-	}
+impl_default!(NMDAYSTATE, 'a);
+
+impl<'a> NMDAYSTATE<'a> {
+	pub_fn_array_buf_get_set!('a, prgDayState, set_prgDayState, cDayState, u32);
 }
 
 /// [`NMITEMACTIVATE`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmitemactivate)
@@ -379,7 +392,7 @@ pub struct NMLVCACHEHINT {
 	pub iTo: i32,
 }
 
-/// [`NMLVCUSTOMDRAW`] (https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmlvcustomdraw)
+/// [`NMLVCUSTOMDRAW`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmlvcustomdraw)
 /// struct.
 #[repr(C)]
 pub struct NMLVCUSTOMDRAW {
@@ -407,8 +420,6 @@ pub struct NMLVDISPINFO<'a> {
 
 /// [`NMLVEMPTYMARKUP`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmlvemptymarkup)
 /// struct.
-///
-/// You cannot directly instantiate this object.
 #[repr(C)]
 pub struct NMLVEMPTYMARKUP {
 	pub hdr: NMHDR,
@@ -416,6 +427,8 @@ pub struct NMLVEMPTYMARKUP {
 	szMarkup: [u16; L_MAX_URL_LENGTH],
 }
 
+impl_default!(NMLVEMPTYMARKUP);
+
 impl NMLVEMPTYMARKUP {
 	pub_fn_string_arr_get_set!(szMarkup, set_szMarkup);
 }
@@ -440,19 +453,18 @@ pub struct NMLVGETINFOTIP<'a> {
 	pub iItem: i32,
 	pub iSubItem: i32,
 	pub lParam: isize,
-	m_pszText: PhantomData<&'a u16>,
+
+	pszText_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(NMLVGETINFOTIP, 'a);
+impl_default!(NMLVGETINFOTIP, 'a);
 
 impl<'a> NMLVGETINFOTIP<'a> {
-	pub_fn_string_buf_get_set!(pszText, set_pszText, cchTextMax);
+	pub_fn_string_buf_get_set!('a, pszText, set_pszText, cchTextMax);
 }
 
 /// [`NMLVKEYDOWN`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmlvkeydown)
 /// struct.
-///
-/// You cannot directly instantiate this object.
 #[repr(C)]
 pub struct NMLVKEYDOWN {
 	pub hdr: NMHDR,
@@ -460,6 +472,8 @@ pub struct NMLVKEYDOWN {
 	flags: u32,
 }
 
+impl_default!(NMLVKEYDOWN);
+
 /// [`NMLVLINK`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmlvlink)
 /// struct.
 #[repr(C)]
@@ -532,24 +546,23 @@ pub struct NMTREEVIEW<'a, 'b> {
 
 /// [`NMTVASYNCDRAW`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmtvasyncdraw)
 /// struct.
-///
-/// You cannot directly instantiate this object.
 #[repr(C)]
-pub struct NMTVASYNCDRAW {
+pub struct NMTVASYNCDRAW<'a> {
 	pub hdr: NMHDR,
-	pimldp: *const IMAGELISTDRAWPARAMS,
+	pimldp: *mut IMAGELISTDRAWPARAMS,
 	pub hr: co::ERROR,
 	pub hItem: HTREEITEM,
 	pub lParam: isize,
 	pub dwRetFlags: co::ADRF,
 	pub iRetImageIndex: i32,
+
+	pimldp_: PhantomData<&'a mut IMAGELISTDRAWPARAMS>,
 }
 
-impl NMTVASYNCDRAW {
-	/// Returns the `pimldp` field.
-	pub fn pimldp(&self) -> &IMAGELISTDRAWPARAMS {
-		unsafe { &*self.pimldp }
-	}
+impl_default!(NMTVASYNCDRAW, 'a);
+
+impl<'a> NMTVASYNCDRAW<'a> {
+	pub_fn_ptr_get_set!('a, pimldp, set_pimldp, IMAGELISTDRAWPARAMS);
 }
 
 /// [`NMTVCUSTOMDRAW`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-nmtvcustomdraw)
@@ -592,6 +605,73 @@ pub struct PBRANGE {
 	pub iHigh: i32,
 }
 
+/// [`TBADDBITMAP`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-tbaddbitmap)
+/// struct.
+#[repr(C)]
+#[derive(Clone)]
+pub struct TBADDBITMAP {
+	hInst: HINSTANCE,
+	nID: usize,
+}
+
+impl_default!(TBADDBITMAP);
+
+impl TBADDBITMAP {
+	/// Returns the `hInst` and `nID` fields.
+	pub fn nID(&self) -> BmpIdbRes {
+		match self.hInst {
+			HINST_COMMCTRL => BmpIdbRes::Idb(co::IDB(self.nID)),
+			HINSTANCE::NULL => BmpIdbRes::Bmp(HBITMAP { ptr: self.nID as _ }),
+			hInst => BmpIdbRes::Res(IdStr::from_ptr(self.nID as _), hInst),
+		}
+	}
+
+	/// Sets the `hInst` and `nID` fields.
+	pub fn set_nID(&mut self, val: &BmpIdbRes) {
+		*self = match val {
+			BmpIdbRes::Idb(idb) => Self { hInst: HINST_COMMCTRL, nID: idb.0 },
+			BmpIdbRes::Bmp(bmp) => Self { hInst: HINSTANCE::NULL, nID: bmp.ptr as _ },
+			BmpIdbRes::Res(res, hInst) => Self { hInst: *hInst, nID: res.as_ptr() as _ },
+		}
+	}
+}
+
+/// [`TBBUTTON`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-tbbutton)
+/// struct.
+#[repr(C)]
+pub struct TBBUTTON<'a> {
+	pub iBitmap: i32,
+	pub idCommand: i32,
+	pub fsState: co::TBSTATE,
+	pub fsStyle: co::BTNS,
+	bReserved: [u8; 6], // assumes 64-bit architecture
+	pub dwData: usize,
+	iString: isize,
+
+	iString_: PhantomData<&'a mut u16>,
+}
+
+impl_default!(TBBUTTON, 'a);
+
+impl<'a> TBBUTTON<'a> {
+	/// Returns the `iString` field.
+	pub fn iString(&self) -> IndexStr {
+		if IS_INTRESOURCE(self.iString as _) {
+			IndexStr::Index(self.iString as _)
+		} else {
+			IndexStr::Str(WString::from_wchars_nullt(self.iString as _))
+		}
+	}
+
+	/// Sets the `iString` field.
+	pub fn set_iString(&mut self, val: &'a mut IndexStr) {
+		self.iString = match val {
+			IndexStr::Index(i) => *i as _,
+			IndexStr::Str(s) => unsafe { s.as_mut_ptr() as _ },
+		};
+	}
+}
+
 /// [`TVINSERTSTRUCT`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-tvinsertstructw)
 /// struct.
 #[repr(C)]
@@ -601,16 +681,16 @@ pub struct TVINSERTSTRUCT<'a> {
 	pub itemex: TVITEMEX<'a>,
 }
 
-impl_default_zero!(TVINSERTSTRUCT, 'a);
+impl_default!(TVINSERTSTRUCT, 'a);
 
 impl<'a> TVINSERTSTRUCT<'a> {
 	/// Returns the `hInsertAfter` field.
-	pub fn hInsertAfter(&self) -> HtreeitemTvi {
-		HtreeitemTvi::from_isize(self.hInsertAfter)
+	pub fn hInsertAfter(&self) -> TreeitemTvi {
+		TreeitemTvi::from_isize(self.hInsertAfter)
 	}
 
 	/// Sets the `hInsertAfter` field.
-	pub fn set_hInsertAfter(&mut self, val: HtreeitemTvi) {
+	pub fn set_hInsertAfter(&mut self, val: TreeitemTvi) {
 		self.hInsertAfter = val.as_isize();
 	}
 }
@@ -629,13 +709,14 @@ pub struct TVITEM<'a> {
 	pub iSelectedImage: i32,
 	pub cChildren: i32,
 	pub lParam: isize,
-	m_pszText: PhantomData<&'a u16>,
+
+	pszText_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(TVITEM, 'a);
+impl_default!(TVITEM, 'a);
 
 impl<'a> TVITEM<'a> {
-	pub_fn_string_buf_get_set!(pszText, set_pszText, cchTextMax);
+	pub_fn_string_buf_get_set!('a, pszText, set_pszText, cchTextMax);
 }
 
 /// [`TVITEMEX`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-tvitemexw)
@@ -657,11 +738,12 @@ pub struct TVITEMEX<'a> {
 	hwnd: HWND,
 	pub iExpandedImage: i32,
 	iReserved: i32,
-	m_pszText: PhantomData<&'a u16>,
+
+	pszText_: PhantomData<&'a mut u16>,
 }
 
-impl_default_zero!(TVITEMEX, 'a);
+impl_default!(TVITEMEX, 'a);
 
 impl<'a> TVITEMEX<'a> {
-	pub_fn_string_buf_get_set!(pszText, set_pszText, cchTextMax);
+	pub_fn_string_buf_get_set!('a, pszText, set_pszText, cchTextMax);
 }
